@@ -52,8 +52,7 @@ $mainclasses = array("desktop" => "",
     );
 $template->assign("mainclasses", $mainclasses);
 
-if (!$userpermissions["admin"]["add"] and $action != "addpro")
-{
+if (!$userpermissions["admin"]["add"] and $action != "addpro") {
     $errtxt = $langfile["nopermission"];
     $noperm = $langfile["accessdenied"];
     $template->assign("errortext", "$errtxt<br>$noperm");
@@ -61,8 +60,7 @@ if (!$userpermissions["admin"]["add"] and $action != "addpro")
     die();
 }
 
-if ($action == "index")
-{
+if ($action == "index") {
     $classes = array("overview" => "overview_active",
         "system" => "system",
         "users" => "users"
@@ -70,8 +68,7 @@ if ($action == "index")
     $template->assign("classes", $classes);
     $title = $langfile['admin'];
     $template->display("admin.tpl");
-} elseif ($action == "users")
-{
+} elseif ($action == "users") {
     $classes = array("overview" => "overview",
         "system" => "system",
         "users" => "active"
@@ -82,22 +79,15 @@ if ($action == "index")
     $roleobj = (object) new roles();
     $roles = $roleobj->getAllRoles();
     $i2 = 0;
-    if (!empty($users))
-    {
-        foreach($users as $usr)
-        {
+    if (!empty($users)) {
+        foreach($users as $usr) {
             $i = 0;
             // $projects = $project->getProjects(1, 10000);
-            if (!empty($projects))
-            {
-                foreach ($projects as $pro)
-                {
-                    if (chkproject($usr["ID"], $pro["ID"]))
-                    {
+            if (!empty($projects)) {
+                foreach ($projects as $pro) {
+                    if (chkproject($usr["ID"], $pro["ID"])) {
                         $chk = 1;
-                    }
-                    else
-                    {
+                    } else {
                         $chk = 0;
                     }
                     $projects[$i]['assigned'] = $chk;
@@ -105,8 +95,7 @@ if ($action == "index")
                 }
             }
             $users[$i2]['projects'] = $projects;
-            if (!empty($users[$i2]['lastlogin']))
-            {
+            if (!empty($users[$i2]['lastlogin'])) {
                 $users[$i2]["lastlogin"] = date("d.m.y / H:i:s", $users[$i2]['lastlogin']);
             }
             $i2 = $i2 + 1;
@@ -119,65 +108,52 @@ if ($action == "index")
     $template->assign("projects", $projects);
     $template->assign("roles", $roles);
     $template->display("adminusers.tpl");
-} elseif ($action == "adduser")
-{
+} elseif ($action == "adduser") {
     $thetag = new tags();
     $tags = $thetag->formatInputTags($tags);
     $admin = $isadmin;
-    if (!isset($admin))
-    {
+    if (!isset($admin)) {
         $admin = 1;
     }
     $sysloc = $settings["locale"];
-    $newid = $user->add($name, $email, 0, $pass, $sysloc, $tags, $rate);
-    if ($newid)
-    {
-        if (!empty($assignto))
-        {
-            foreach ($assignto as $proj)
-            {
+
+    $newid = $user->add($name, $email, $company, $pass, $sysloc, $tags, $rate);
+    if ($newid) {
+        if (!empty($assignto)) {
+            foreach ($assignto as $proj) {
                 $project->assign($newid, $proj);
             }
         }
         $roleobj = (object) new roles();
         $roleobj->assign($role, $newid);
 
-        if ($settings["mailnotify"])
-        {
-            if (!empty($email))
-            {
+        if ($settings["mailnotify"]) {
+            if (!empty($email)) {
                 // send email
                 $themail = new emailer($settings);
-				$themail->send_mail($email, $langfile["profileaddedsubject"] , $langfile["profileaddedtext"] . "<br /><br />" . $langfile["profileusername"] . ":&nbsp;" . "$name<br />" . $langfile["profilepass"] . ":&nbsp;" . "$pass<br /><br />" . "<a href = \"$url\">$url</a>");
+                $themail->send_mail($email, $langfile["profileaddedsubject"], $langfile["hello"] . ",<br /><br/>" . $langfile["profileaddedtext"] . "<br /><br />" . $langfile["profileusername"] . ":&nbsp;" . "$name<br />" . $langfile["profilepass"] . ":&nbsp;" . "$pass<br /><br />" . "<a href = \"$url\">$url</a>");
             }
         }
         header("Location: admin.php?action=users&mode=added");
-    }
-    else
-    {
+    } else {
         $goback = $langfile["goback"];
         $endafterstart = $langfile["endafterstart"];
-        $template->assign("errortext", "The email address $email or the username $name already exists in the Userdatabase.<br>$goback");
+        $template->assign("errortext", "The email address $email or the username $name already exists in the user database.<br>$goback");
         $template->display("error.tpl");
     }
-} elseif ($action == "editform")
-{
+} elseif ($action == "editform") {
     $roleobj = (object) new roles();
     $roles = $roleobj->getAllRoles();
 
     $languages_fin = array();
-    foreach($languages as $lang)
-    {
+    foreach($languages as $lang) {
         $lang2 = $langfile[$lang];
         $fin = countLanguageStrings($lang);
 
-        if (!empty($lang2))
-        {
+        if (!empty($lang2)) {
             $lang2 .= " (" . $fin . "%)";
             $fin = array("val" => $lang, "str" => $lang2);
-        }
-        else
-        {
+        } else {
             $lang2 = $lang . " (" . $fin . "%)";
             $fin = array("val" => $lang, "str" => $lang2);
         }
@@ -194,24 +170,20 @@ if ($action == "index")
     $template->assign("user", $user);
     $template->assign("roles", $roles);
     $template->display("edituseradminform.tpl");
-} elseif ($action == "edituser")
-{
+} elseif ($action == "edituser") {
     $thetag = new tags();
     $tags = $thetag->formatInputTags($tags);
 
     $roleobj = new roles();
     $roleobj->assign($role, $id);
-    if ($id == $userid)
-    {
+    if ($id == $userid) {
         $_SESSION['userlocale'] = $locale;
         $_SESSION['username'] = $name;
     }
-    if (!isset($isadmin))
-    {
+    if (!isset($isadmin)) {
         $isadmin = 1;
     }
-    if (!empty($_FILES['userfile']['name']))
-    {
+    if (!empty($_FILES['userfile']['name'])) {
         $fname = $_FILES['userfile']['name'];
         $typ = $_FILES['userfile']['type'];
         $size = $_FILES['userfile']['size'];
@@ -226,15 +198,13 @@ if ($action == "index")
         $erweiterung = $teilnamen[$workteile];
 
         $subname = "";
-        if ($typ != "image/jpeg" and $typ != "image/png" and $typ != "image/gif")
-        {
+        if ($typ != "image/jpeg" and $typ != "image/png" and $typ != "image/gif") {
             $loc = $url . "manageuser.php?action=profile&id=$userid";
             header("Location: $loc");
             die();
         }
 
-        for ($i = 0; $i < $workteile; $i++)
-        {
+        for ($i = 0; $i < $workteile; $i++) {
             $subname .= $teilnamen[$i];
         }
         list($usec, $sec) = explode(' ', microtime());
@@ -245,8 +215,7 @@ if ($action == "index")
         $subname = preg_replace("/[^-_0-9a-zA-Z]/", "_", $subname);
         $subname = preg_replace("/\W/", "", $subname);
 
-        if (strlen($subname) > 200)
-        {
+        if (strlen($subname) > 200) {
             $subname = substr($subname, 0, 200);
         }
 
@@ -254,42 +223,32 @@ if ($action == "index")
 
         $datei_final = CL_ROOT . "/files/" . CL_CONFIG . "/avatar/" . $fname;
 
-        if (move_uploaded_file($tmp_name, $datei_final))
-        {
+        if (move_uploaded_file($tmp_name, $datei_final)) {
             $avatar = $fname;
         }
 
-        if ($user->edit($id, $name, "" , $email, $tel1, $tel2, $company, $zip, $gender, $turl, $address1, $address2, $state, $country, $tags, $locale, $avatar, $rate))
-        {
-            if (!empty($newpass) and !empty($repeatpass))
-            {
+        if ($user->edit($id, $name, "" , $email, $tel1, $tel2, $company, $zip, $gender, $turl, $address1, $address2, $state, $country, $tags, $locale, $avatar, $rate)) {
+            if (!empty($newpass) and !empty($repeatpass)) {
+                $user->admin_editpass($id, $newpass, $repeatpass);
+            }
+            header("Location: admin.php?action=users&mode=edited");
+        }
+    } else {
+        if ($user->edit($id, $name, "", $email, $tel1, $tel2, $company, $zip, $gender, $turl, $address1, $address2, $state, $country, $tags, $locale, "", $rate)) {
+            if (!empty($newpass) and !empty($repeatpass)) {
                 $user->admin_editpass($id, $newpass, $repeatpass);
             }
             header("Location: admin.php?action=users&mode=edited");
         }
     }
-    else
-    {
-        if ($user->edit($id, $name, "", $email, $tel1, $tel2, $company, $zip, $gender, $turl, $address1, $address2, $state, $country, $tags, $locale, "", $rate))
-        {
-            if (!empty($newpass) and !empty($repeatpass))
-            {
-                $user->admin_editpass($id, $newpass, $repeatpass);
-            }
-            header("Location: admin.php?action=users&mode=edited");
-        }
-    }
-} elseif ($action == "deleteuserform")
-{
+} elseif ($action == "deleteuserform") {
     $usr = $user->getProfile($id);
     // Get user's projects
     $proj = new project();
     $projects = $proj->getMyProjects($id);
     // Get members of each project
-    if (!empty($projects))
-    {
-        for ($i = 0; $i < count($projects); $i++)
-        {
+    if (!empty($projects)) {
+        for ($i = 0; $i < count($projects); $i++) {
             $members = $proj->getProjectMembers($projects[$i]["ID"]);
             $projects[$i]["members"] = $members;
         }
@@ -300,54 +259,38 @@ if ($action == "index")
         $template->assign("user", $usr);
         $template->assign("projects", $projects);
         $template->display("admindeluserform.tpl");
-    }
-    else
-    {
-        if ($user->del($id))
-        {
+    } else {
+        if ($user->del($id)) {
             header("Location: admin.php?action=users&mode=deleted");
         }
     }
-} elseif ($action == "deleteuser")
-{
-
+} elseif ($action == "deleteuser") {
     $id = getArrayVal($_POST, "id");
     $uprojects = getArrayVal($_POST, "uprojects");
 
     $proarr = array();
-    foreach($uprojects as $upro)
-    {
+    foreach($uprojects as $upro) {
         $dat = explode("#", $upro);
         $todo = array("project" => $dat[0], "user" => $dat[1]);
         array_push($proarr, $todo);
     }
 
-    if (!empty($proarr))
-    {
+    if (!empty($proarr)) {
         $task = new task();
 
-        foreach($proarr as $proj)
-        {
+        foreach($proarr as $proj) {
             $tasks = $task->getAllMyProjectTasks($proj["project"], 100, $id);
-            if ($proj["project"] > 0 and $proj["user"] > 0)
-            {
-                if (!empty($tasks))
-                {
-                    foreach($tasks as $mytask)
-                    {
-                        if ($task->deassign($mytask["ID"], $id))
-                        {
+            if ($proj["project"] > 0 and $proj["user"] > 0) {
+                if (!empty($tasks)) {
+                    foreach($tasks as $mytask) {
+                        if ($task->deassign($mytask["ID"], $id)) {
                             $task->assign($mytask["ID"], $proj["user"]);
                         }
                     }
                 }
-            }
-            else
-            {
-                if (!empty($tasks))
-                {
-                    foreach($tasks as $mytask)
-                    {
+            } else {
+                if (!empty($tasks)) {
+                    foreach($tasks as $mytask) {
                         $task->del($mytask["ID"]);
                     }
                 }
@@ -355,22 +298,16 @@ if ($action == "index")
         }
     }
 
-    if ($user->del($id))
-    {
+    if ($user->del($id)) {
         header("Location: admin.php?action=users&mode=deleted");
     }
-} elseif ($action == "assignform")
-{
+} elseif ($action == "assignform") {
     $projects = $project->getProjects(1, 10000);
     $i = 0;
-    foreach ($projects as $project)
-    {
-        if (chkproject($id, $project[ID]))
-        {
+    foreach ($projects as $project) {
+        if (chkproject($id, $project[ID])) {
             $chk = 1;
-        }
-        else
-        {
+        } else {
             $chk = 0;
         }
         $projects[$i]['assigned'] = $chk;
@@ -380,59 +317,46 @@ if ($action == "index")
     $user = $user->getProfile($id);
     $template->assign("user", $user);
     $template->display("assignform.tpl");
-} elseif ($action == "massassign")
-{
+} elseif ($action == "massassign") {
     $projects = $_POST['projects'];
     $user = $_POST['id'];
     $allprojects = $project->getProjects(1, 10000);
     $allpro = array();
-    foreach($allprojects as $pro)
-    {
+    foreach($allprojects as $pro) {
         array_push($allpro, $pro[ID]);
     }
 
-    if (!empty($allpro) and !empty($projects))
-    {
+    if (!empty($allpro) and !empty($projects)) {
         $diff = array_diff($allpro, $projects);
-    } elseif (empty($projects))
-    {
+    } elseif (empty($projects)) {
         $diff = $allpro;
     }
 
-    if (!empty($projects))
-    {
-        foreach($projects as $pro)
-        {
-            if (!chkproject($user, $pro))
-            {
-                if ($settings["mailnotify"])
-                {
+    if (!empty($projects)) {
+        foreach($projects as $pro) {
+            if (!chkproject($user, $pro)) {
+                if ($settings["mailnotify"]) {
                     $usr = (object) new user();
                     $tuser = $usr->getProfile($user);
 
-                    if (!empty($tuser["email"]))
-                    {
+                    if (!empty($tuser["email"])) {
                         // send email
                         $themail = new emailer($settings);
-						$themail->send_mail($tuser["email"], $langfile["projectassignedsubject"] , $langfile["hello"] . ",<br /><br/>" . $langfile["projectassignedtext"] . " <a href = \"" . $url . "manageproject.php?action=showproject&id=$pro\">" . $url . "manageproject.php?action=showproject&id=$pro</a>");
+                        $themail->send_mail($tuser["email"], $langfile["projectassignedsubject"] , $langfile["hello"] . ",<br /><br/>" . $langfile["projectassignedtext"] . " <a href = \"" . $url . "manageproject.php?action=showproject&id=$pro\">" . $url . "manageproject.php?action=showproject&id=$pro</a>");
                     }
                 }
                 $project->assign($user, $pro);
             }
         }
     }
-    if (!empty($diff))
-    {
-        foreach($diff as $mydiff)
-        {
+    if (!empty($diff)) {
+        foreach($diff as $mydiff) {
             $project->deassign($user, $mydiff);
         }
     }
 
     header("Location: admin.php?action=users&mode=de-assigned");
-}
-elseif ($action == "projects")
-{
+} elseif ($action == "projects") {
     $classes = array("overview" => "active",
         "system" => "system",
         "users" => "users"
@@ -444,10 +368,8 @@ elseif ($action == "projects")
     $clopros = $project->getProjects(0, 10000);
     $i = 0;
     $users = $user->getAllUsers(1000000);
-    if (!empty($opros))
-    {
-        foreach($opros as $opro)
-        {
+    if (!empty($opros)) {
+        foreach($opros as $opro) {
             $membs = $project->getProjectMembers($opro["ID"], 1000);
             $opros[$i]['members'] = $membs;
             $i = $i + 1;
@@ -458,11 +380,8 @@ elseif ($action == "projects")
     $template->assign("users", $users);
     $template->assign("clopros", $clopros);
     $template->display("adminprojects.tpl");
-}
-elseif ($action == "addpro")
-{
-    if (!$userpermissions["projects"]["add"])
-    {
+} elseif ($action == "addpro") {
+    if (!$userpermissions["projects"]["add"]) {
         $errtxt = $langfile["nopermission"];
         $noperm = $langfile["accessdenied"];
         $template->assign("errortext", "$errtxt<br>$noperm");
@@ -470,67 +389,60 @@ elseif ($action == "addpro")
         die();
     }
 
-	if (!$end)
-	{
-		$end = 0;
-	}
+    if (!$end) {
+        $end = 0;
+    }
 
     $add = $project->add($name, $desc, $end, $budget, 0);
-    if ($add)
-    {
-        foreach ($assignto as $member)
-        {
+    if ($add) {
+        foreach ($assignto as $member) {
             $project->assign($member, $add);
+
+            if ($settings["mailnotify"]) {
+                $usr = (object) new user();
+                $user = $usr->getProfile($member);
+
+                if (!empty($user["email"])) {
+                    // send email
+                    $themail = new emailer($settings);
+                    $themail->send_mail($user["email"], $langfile["projectassignedsubject"] , $langfile["hello"] . ",<br /><br/>" . $langfile["projectassignedtext"] . " <a href = \"" . $url . "manageproject.php?action=showproject&id=$id\">" . $url . "manageproject.php?action=showproject&id=$add</a>");
+                }
+            }
         }
-		if($userpermissions["admin"]["add"])
-		{
-			header("Location: admin.php?action=projects&mode=added");
-		}
-		else
-		{
-			header("Location: index.php?mode=projectadded");
-		}
-	}
-} elseif ($action == "closepro")
-{
-    if ($project->close($id))
-    {
+        if ($userpermissions["admin"]["add"]) {
+            header("Location: admin.php?action=projects&mode=added");
+        } else {
+            header("Location: index.php?mode=projectadded");
+        }
+    }
+} elseif ($action == "closepro") {
+    if ($project->close($id)) {
         echo "ok";
         // header("Location: admin.php?action=projects&mode=closed");
     }
-} elseif ($action == "openpro")
-{
-    if ($project->open($id))
-    {
+} elseif ($action == "openpro") {
+    if ($project->open($id)) {
         header("Location: admin.php?action=projects&mode=opened");
     }
-} elseif ($action == "deletepro")
-{
-    if ($project->del($id))
-    {
+} elseif ($action == "deletepro") {
+    if ($project->del($id)) {
         // header("Location: admin.php?action=projects&mode=deleted");
         echo "ok";
     }
-} elseif ($action == "system")
-{
+} elseif ($action == "system") {
     $classes = array("overview" => "overview",
         "system" => "active",
         "users" => "users"
         );
 
     $languages_fin = array();
-    foreach($languages as $lang)
-    {
-        $lang2 = $langfile[$lang];
+    foreach($languages as $lang) {
         $fin = countLanguageStrings($lang);
-
-        if (!empty($lang2))
-        {
+        if (!empty($langfile[$lang])) {
+            $lang2 = $langfile[$lang];
             $lang2 .= " (" . $fin . "%)";
             $fin = array("val" => $lang, "str" => $lang2);
-        }
-        else
-        {
+        } else {
             $lang2 = $lang . " (" . $fin . "%)";
             $fin = array("val" => $lang, "str" => $lang2);
         }
@@ -558,29 +470,23 @@ elseif ($action == "addpro")
     $template->assign("timezones", $timezones);
     $template->assign("templates", $templates);
     $template->display("editsettings.tpl");
-} elseif ($action == "editsets")
-{
-    if ($theset->editSettings($name, $subtitle, $locale, $timezone, $dateformat, $templ, $rssuser, $rsspass))
-    {
+} elseif ($action == "editsets") {
+    if ($theset->editSettings($name, $subtitle, $locale, $timezone, $dateformat, $templ, $rssuser, $rsspass)) {
         $handle = opendir($template->compile_dir);
-        while (false !== ($file = readdir($handle)))
-        {
-            if ($file != "." and $file != "..")
-            {
+        while (false !== ($file = readdir($handle))) {
+            if ($file != "." and $file != "..") {
                 unlink(CL_ROOT . "/" . $template->compile_dir . "/" . $file);
             }
         }
         $_SESSION["userlocale"] = $locale;
         $users = $user->getAllUsers(100000);
-        foreach($users as $theuser)
-        {
+        foreach($users as $theuser) {
             // set the new locale for all the users
             $user->edit($theuser["ID"], $theuser["name"], $theuser["realname"], $theuser["email"], $theuser["tel1"], $theuser["tel2"], $theuser["company"], $theuser["zip"], $theuser["gender"], $theuser["url"], $theuser["adress"], $theuser["adress2"], $theuser["state"], $theuser["country"], $theuser["tags"], $locale, "", $theuser["rate"]);
         }
         header("Location: admin.php?action=system&mode=edited");
     }
-} elseif ($action == "editmailsets")
-{
+} elseif ($action == "editmailsets") {
     $status = getArrayVal($_POST, "mailstatus");
     $mailfrom = getArrayVal($_POST, "mailfrommail");
     $mailfromname = getArrayVal($_POST, "mailfromname");
@@ -589,8 +495,7 @@ elseif ($action == "addpro")
     $mailuser = getArrayVal($_POST, "mailuser");
     $mailpass = getArrayVal($_POST, "mailpass");
 
-    if ($theset->editMailsettings($status, $mailfrom, $mailfromname, $method, $server, $mailuser, $mailpass))
-    {
+    if ($theset->editMailsettings($status, $mailfrom, $mailfromname, $method, $server, $mailuser, $mailpass)) {
         header("Location: admin.php?action=system&mode=edited");
     }
 }
