@@ -4,46 +4,39 @@
  *
  * @author Open Dynamics / Philipp Kiszka <info@o-dyn.de>
  * @name datei
- * @version 0.7
  * @package Collabtive
+ * @version 1.0
  * @link http://www.o-dyn.de
  * @license http://opensource.org/licenses/gpl-license.php GNU General Public License v3 or later
  */
-class datei
-{
+class datei {
     /**
      * Constructor
-     * Initialize the event log
+     *
+     * @access protected
      */
     function __construct()
     {
+        // Initialize event lof
         $this->mylog = new mylog;
     }
-
     // FOLDER METHODS
     /**
      * Create a new folder
      *
-     * @param int $project Project ID the folder belongs to
+     * @param int $parent ID of the parent folder
+     * @param int $project ID of the project the folder belongs to
      * @param string $folder Name of the new folder
-     * @param string $desc Description of the folder
+     * @param string $desc Description of the new folder
+     * @param strin $visible Visibility of the new folder
      * @return bool
      */
     function addFolder($parent, $project, $folder, $desc, $visible = "")
     {
+        global $conn;
         $project = (int) $project;
-        $folder = mysql_real_escape_string($folder);
         $folderOrig = $folder;
-        $desc = mysql_real_escape_string($desc);
-        if(!empty($visible))
-        {
-			$visstr = serialize($visible);
-		}
-		else
-		{
-			$visstr = "";
-		}
-
+        // replace umlauts
         $folder = str_replace("ä", "ae" , $folder);
         $folder = str_replace("ö", "oe" , $folder);
         $folder = str_replace("ü", "ue" , $folder);
@@ -52,29 +45,23 @@ class datei
         $folder = preg_replace("/\W/", "", $folder);
         $folder = preg_replace("/[^-_0-9a-zA-Z]/", "_", $folder);
         // insert the folder into the db
-        $ins = mysql_query("INSERT INTO projectfolders (parent,project,name,description,visible) VALUES ($parent,$project,'$folder','$desc','$visstr')");
-        if ($ins)
-        {
+        $insStmt = $conn->prepare("INSERT INTO projectfolders (parent, project, name, description, visible) VALUES (?, ?, ?, ?, ?)");
+        $ins = $insStmt->execute(array($parent, $project, $folder, $desc, $visible));
+        if ($ins) {
             // create the folder
             $makefolder = CL_ROOT . "/files/" . CL_CONFIG . "/$project/$folder/";
-            if (!file_exists($makefolder))
-            {
-                if (mkdir($makefolder, 0777, true))
-                {
+            if (!file_exists($makefolder)) {
+                if (mkdir($makefolder, 0777, true)) {
                     // folder created
-					$this->mylog->add($folderOrig, 'folder', 1, $project);
+                    $this->mylog->add($folderOrig, 'folder', 1, $project);
                     return true;
                 }
-            }
-            else
-            {
+            } else {
                 // folder already existed, return false
                 return false;
             }
-        }
-        else
-        {
-            // folder wasnt created , return false
+        } else {
+            // folder could not be created, return false
             return false;
         }
     }
@@ -83,141 +70,157 @@ class datei
      * Delete a folder
      * Deletes the given folder with all files in it and all of its subfolders.
      *
-     * @param int $id folder id
-     * @param int $id project id
+     * @param int $id Folder ID
+     * @param int $project Project ID
      * @return bool
      */
     function deleteFolder($id, $project)
     {
+        global $conn;
         $id = (int) $id;
+        $project = (int) $project;
         $folder = $this->getFolder($id);
+
         $files = $this->getProjectFiles($project, 10000, $id);
         // delete all the files in the folder from the database (and filesystem as well)
-        foreach($files as $file)
-        {
-            $this->loeschen($file["ID"]);
+        if (!empty($files)) {
+            foreach($files as $file) {
+                $this->loeschen($file["ID"]);
+            }
         }
-        if (!empty($folder["subfolders"]))
-        {
-            foreach($folder["subfolders"] as $sub)
-            {
+        if (!empty($folder["subfolders"])) {
+            foreach($folder["subfolders"] as $sub) {
                 $this->deleteFolder($sub["ID"], $sub["project"]);
             }
         }
-        $del = mysql_query("DELETE FROM projectfolders WHERE ID = $id");
-        if ($del)
-		{
-			// remove directory
-			$foldstr = CL_ROOT . "/files/" . CL_CONFIG . "/$project/" . $folder["name"] . "/";
-			delete_directory($foldstr);
-			$this->mylog->add($folder["name"], 'folder', 3, $project);
-			return true;
-		}
+        $del = $conn->query("DELETE FROM projectfolders WHERE ID = $id");
+        if ($del) {
+            // remove directory
+            $foldstr = CL_ROOT . "/files/" . CL_CONFIG . "/$project/" . $folder["name"] . "/";
+            delete_directory($foldstr);
+            $this->mylog->add($folder["name"], 'folder', 3, $project);
+            return true;
+        }
     }
 
     /**
-     * Get directory
+     * Get a folder
      *
-     * @param string $id Directory
-     * @return array $files Found files and directories
+     * @param int $id Folder ID
+     * @return array $folder
      */
     function getFolder($id)
     {
+        global $conn;
         $id = (int) $id;
-        $sel = mysql_query("SELECT * FROM projectfolders WHERE ID = $id LIMIT 1");
-        $folder = mysql_fetch_array($sel);
+        $folder = $conn->query("SELECT * FROM projectfolders WHERE ID = $id LIMIT 1")->fetch();
         $folder["subfolders"] = $this->getSubFolders($folder["ID"]);
+        $folder["abspath"] = $this->getAbsolutePathName($folder);
 
         return $folder;
     }
 
     /**
-     * Recursively get subdirectories of a given directory
+     * Recursively get all subfolders of a given folder
      *
-     * @param int $id Directory
-     * @return array $files Found files and directories
+     * @param int $parent ID of the parent folder
+     * @return array $folders
      */
     function getSubFolders($parent)
     {
+        global $conn;
         $parent = (int) $parent;
-        $sel = mysql_query("SELECT * FROM projectfolders WHERE parent = $parent");
+        $sel = $conn->query("SELECT * FROM projectfolders WHERE parent = $parent ORDER BY ID ASC");
 
         $folders = array();
 
-        while ($folder = mysql_fetch_array($sel))
-        {
+        while ($folder = $sel->fetch()) {
             $folder["subfolders"] = $this->getSubFolders($folder["ID"]);
+            $folder["abspath"] = $this->getAbsolutePathName($folder);
             array_push($folders, $folder);
         }
 
-        if (!empty($folders))
-        {
+        if (!empty($folders)) {
             return $folders;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
 
     /**
-     * Get all the directories in a project
+     * Get all the folders in a project
      *
-     * @param string $id project Project ID
-     * @return array $files Found files and directories
+     * @param int $project Project ID
+     * @param int $parent Parent folder ID
+     * @return array $folders
      */
     function getProjectFolders($project, $parent = 0)
     {
+        global $conn;
         $project = (int) $project;
 
-        $sel = mysql_query("SELECT * FROM projectfolders WHERE project = $project AND parent = $parent");
+        $sel = $conn->query("SELECT * FROM projectfolders WHERE project = $project AND parent = $parent ORDER BY ID ASC");
         $folders = array();
 
-        while ($folder = mysql_fetch_array($sel))
-        {
+        while ($folder = $sel->fetch()) {
             $folder["subfolders"] = $this->getSubFolders($folder["ID"]);
+            $folder["abspath"] = $this->getAbsolutePathName($folder);
             array_push($folders, $folder);
         }
 
-        if (!empty($folders))
-        {
+        if (!empty($folders)) {
             return $folders;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
 
     /**
-     * Get all the directories in a project
+     * Get all the folders in a project
      *
      * @param string $id project Project ID
-     * @return array $files Found files and directories
+     * @return array $folders
      */
     function getAllProjectFolders($project)
     {
+        global $conn;
         $project = (int) $project;
 
-        $sel = mysql_query("SELECT * FROM projectfolders WHERE project = $project");
+        $sel = $conn->query("SELECT * FROM projectfolders WHERE project = $project ORDER BY ID ASC");
         $folders = array();
 
-        while ($folder = mysql_fetch_array($sel))
-        {
+        while ($folder = $sel->fetch()) {
             $folder["subfolders"] = $this->getSubFolders($folder["ID"]);
+            $folder["abspath"] = $this->getAbsolutePathName($folder);
             array_push($folders, $folder);
         }
 
-        if (!empty($folders))
-        {
+        if (!empty($folders)) {
             return $folders;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
 
+    /**
+     * Get an absolute path name
+     * Returns the absolute name (relative to the root-directory of the project) of a folder.
+     *
+     * @param array $folder The folder to be inspected
+     * @return string Absolute path/name of the folder
+     */
+    function getAbsolutePathName($folder)
+    {
+        global $conn;
+        if ($folder['parent'] == 0) {
+            return "/" . $folder['name'];
+        } else {
+            $sel = $conn->query("SELECT * FROM projectfolders WHERE ID = " . $folder['parent']);
+            $parent = $sel->fetch();
+
+            return $this->getAbsolutePathName($parent) . "/" . $folder['name'];
+        }
+    }
     // FILE METHODS
     /**
      * Upload a file
@@ -227,6 +230,7 @@ class datei
      * @param string $fname Name of the HTML form field POSTed from
      * @param string $ziel Destination directory
      * @param int $project Project ID of the associated project
+     * @param int $folder
      * @return bool
      */
     function upload($fname, $ziel, $project, $folder = 0)
@@ -239,12 +243,9 @@ class datei
         $tastr = $fname . "-tags";
         $visible = $_POST["visible"];
 
-        if (!empty($visible[0]))
-        {
+        if (!empty($visible[0])) {
             $visstr = serialize($visible);
-        }
-        else
-        {
+        } else {
             $visstr = "";
         }
 
@@ -253,8 +254,7 @@ class datei
         $error = $_FILES[$fname]['error'];
         $root = CL_ROOT;
 
-        if (empty($name))
-        {
+        if (empty($name)) {
             return false;
         }
 
@@ -269,14 +269,12 @@ class datei
         $erweiterung = $teilnamen[$workteile];
         $subname = "";
         // if its a php file, treat it as plaintext so its not executed when opened in the browser.
-        if (stristr($erweiterung, "php"))
-        {
+        if (stristr($erweiterung, "php")) {
             $erweiterung = "txt";
             $typ = "text/plain";
         }
 
-        for ($i = 0; $i < $workteile; $i++)
-        {
+        for ($i = 0; $i < $workteile; $i++) {
             $subname .= $teilnamen[$i];
         }
 
@@ -290,8 +288,7 @@ class datei
         // remove whitespace
         $subname = preg_replace("/\W/", "", $subname);
         // if filename is longer than 200 chars, cut it.
-        if (strlen($subname) > 200)
-        {
+        if (strlen($subname) > 200) {
             $subname = substr($subname, 0, 200);
         }
 
@@ -299,44 +296,115 @@ class datei
         $datei_final = $root . "/" . $ziel . "/" . $name;
         $datei_final2 = $ziel . "/" . $name;
 
-        if (!file_exists($datei_final))
-        {
-            if (move_uploaded_file($tmp_name, $datei_final))
-            {
-               // $filesize = filesize($datei_final);
+        if (!file_exists($datei_final)) {
+            if (move_uploaded_file($tmp_name, $datei_final)) {
+                // $filesize = filesize($datei_final);
+                if ($project > 0) {
+                    // file did not already exist, was uploaded, and a project is set
+                    // add the file to the database, add the upload event to the log and return the file ID.
+                    chmod($datei_final, 0755);
+                    $fid = $this->add_file($name, $desc, $project, 0, "$tags", $datei_final2, "$typ", $title, $folder, $visstr);
+                    if (!empty($title)) {
+                        $this->mylog->add($title, 'file', 1, $project);
+                    } else {
+                        $this->mylog->add($name, 'file', 1, $project);
+                    }
+                    return $fid;
+                } else {
+                    // no project means the file is not added to the database wilfully. return file name.
+                    return $name;
+                }
+            } else {
+                // file was not uploaded / error occured. return false
+                return false;
+            }
+        } else {
+            // file already exists. return false
+            return false;
+        }
+    }
 
-                if ($project > 0)
-                {
+    /**
+     * Upload a file
+     * Does filename sanitizing as well as MIME-type determination
+     * Also adds the file to the database using add_file()
+     *
+     * @param string $fname Name of the HTML form field POSTed from
+     * @param string $ziel Destination directory
+     * @param int $project Project ID of the associated project
+     * @return bool
+     */
+    function uploadAsync($name, $tmp_name, $typ, $size, $ziel, $project, $folder = 0)
+    {
+        $visible = "";
+        $visstr = "";
+        $root = CL_ROOT;
+
+        if (empty($name)) {
+            return false;
+        }
+        // find the extension
+        $teilnamen = explode(".", $name);
+        $teile = count($teilnamen);
+        $workteile = $teile - 1;
+        $erweiterung = $teilnamen[$workteile];
+        $subname = "";
+        // if its a php file, treat it as plaintext so its not executed when opened in the browser.
+        if (stristr($erweiterung, "php")) {
+            $erweiterung = "txt";
+            $typ = "text/plain";
+        }
+
+        for ($i = 0; $i < $workteile; $i++) {
+            $subname .= $teilnamen[$i];
+        }
+
+        $randval = mt_rand(1, 99999);
+        // only allow a-z , 0-9 in filenames, substitute other chars with _
+        $subname = str_replace("ä", "ae" , $subname);
+        $subname = str_replace("ö", "oe" , $subname);
+        $subname = str_replace("ü", "ue" , $subname);
+        $subname = str_replace("ß", "ss" , $subname);
+        $subname = preg_replace("/[^-_0-9a-zA-Z]/", "_", $subname);
+        // remove whitespace
+        $subname = preg_replace("/\W/", "", $subname);
+        // if filename is longer than 200 chars, cut it.
+        if (strlen($subname) > 200) {
+            $subname = substr($subname, 0, 200);
+        }
+
+        $name = $subname . "_" . $randval . "." . $erweiterung;
+        $datei_final = $root . "/" . $ziel . "/" . $name;
+        $datei_final2 = $ziel . "/" . $name;
+
+        if (!file_exists($datei_final)) {
+            if (move_uploaded_file($tmp_name, $datei_final)) {
+                // $filesize = filesize($datei_final);
+                if ($project > 0) {
                     /**
                      * file did not already exist, was uploaded, and a project is set
                      * add the file to the database, add the upload event to the log and return the file ID.
                      */
+                    if (!$title) {
+                        $title = $name;
+                    }
                     chmod($datei_final, 0755);
                     $fid = $this->add_file($name, $desc, $project, 0, "$tags", $datei_final2, "$typ", $title, $folder, $visstr);
-					if(!empty($title))
-					{
-						$this->mylog->add($title, 'file', 1, $project);
+                    if (!empty($title)) {
+                        $this->mylog->add($title, 'file', 1, $project);
+                    } else {
+                        $this->mylog->add($name, 'file', 1, $project);
                     }
-					else
-					{
-						$this->mylog->add($name, 'file', 1, $project);
-					}
-					return $fid;
-                }
-                else
-                {
+                    return $fid;
+                } else {
                     // no project means the file is not added to the database wilfully. return file name.
                     return $name;
                 }
-            }
-            else
-            {
+            } else {
                 // file was not uploaded / error occured. return false
                 return false;
             }
-        }
-        else
-        {
+        } else {
             // file already exists. return false
             return false;
         }
@@ -353,23 +421,19 @@ class datei
      */
     function edit($id, $title, $desc, $tags)
     {
+        global $conn;
         $id = (int) $id;
-        $title = mysql_real_escape_string($title);
-        $desc = mysql_real_escape_string($desc);
-        $tags = mysql_real_escape_string($tags);
         // get project for logging
-        $sel = mysql_query("SELECT project FROM files WHERE ID = $id");
-        $proj = mysql_fetch_row($sel);
+        $proj = $conn->query("SELECT project FROM files WHERE ID = $id")->fetch();
         $project = $proj[0];
 
-        $sql = mysql_query("UPDATE files SET `title` = '$title', `desc` = '$desc', `tags` = '$tags' WHERE id = $id");
-        if ($sql)
-        {
+        $sql = $conn->prepare("UPDATE files SET `title` = ?, `desc` = ?, `tags` = ? WHERE id = ?");
+        $upd = $sql->execute(array($title, $desc, $tags, $id));
+
+        if ($sql) {
             $this->mylog->add($title, 'file' , 2, $project);
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -382,12 +446,11 @@ class datei
      */
     function loeschen($datei)
     {
+        global $conn;
         $datei = (int) $datei;
 
-        $sel1 = mysql_query("SELECT datei,name,project,title FROM files WHERE ID = $datei");
-        $thisfile = mysql_fetch_row($sel1);
-        if (!empty($thisfile))
-        {
+        $thisfile = $conn->query("SELECT datei,name,project,title FROM files WHERE ID = $datei")->fetch();
+        if (!empty($thisfile)) {
             $fname = $thisfile[1];
             $project = $thisfile[2];
             $ftitle = $thisfile[3];
@@ -395,31 +458,24 @@ class datei
 
             $delfile = "./" . $thisfile;
 
-            if (!file_exists($delfile))
-            {
+            if (!file_exists($delfile)) {
                 return false;
             }
-            $del = mysql_query("DELETE FROM files WHERE ID = $datei");
-            $del2 = mysql_query("DELETE FROM files_attached WHERE file = $datei");
-            if ($del)
-            {
-                if (unlink($delfile))
-                {
-					if ($ftitle != "") {
-						$this->mylog->add($ftitle, 'file', 3, $project);
-					} else {
-						$this->mylog->add($fname, 'file', 3, $project);
-					}
+            $del = $conn->query("DELETE FROM files WHERE ID = $datei");
+            $del2 = $conn->query("DELETE FROM files_attached WHERE file = $datei");
+            if ($del) {
+                if (unlink($delfile)) {
+                    if ($ftitle != "") {
+                        $this->mylog->add($ftitle, 'file', 3, $project);
+                    } else {
+                        $this->mylog->add($fname, 'file', 3, $project);
+                    }
                     return true;
-                }
-                else
-                {
+                } else {
                     return false;
                 }
             }
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -430,36 +486,29 @@ class datei
      * @param string $id File ID
      * @return array $file File details
      */
-
     function getFile($id)
     {
+        global $conn;
         $id = (int) $id;
         // get the file from MySQL
-        $sel = mysql_query("SELECT * FROM files WHERE ID=$id");
-        $file = mysql_fetch_array($sel);
+        $file = $conn->query("SELECT * FROM files WHERE ID=$id")->fetch();
 
-        if (!empty($file))
-        {
+        if (!empty($file)) {
             // determine if there is an mimetype icon corresponding to the files mimetype. If not set 'none'
             $file['type'] = str_replace("/", "-", $file["type"]);
 
             $set = new settings();
             $settings = $set->getSettings();
             $myfile = "./templates/" . $settings["template"] . "/images/files/" . $file['type'] . ".png";
-            if (!file_exists($myfile))
-            {
+            if (!file_exists($myfile)) {
                 $file['type'] = "none";
             }
             // determine if its an image or textfile or some other file. this is needed for lightboxes
-            if (stristr($file['type'], "image"))
-            {
+            if (stristr($file['type'], "image")) {
                 $file['imgfile'] = 1;
-            } elseif (stristr($file['type'], "text"))
-            {
+            } elseif (stristr($file['type'], "text")) {
                 $file['imgfile'] = 2;
-            }
-            else
-            {
+            } else {
                 $file['imgfile'] = 0;
             }
             // split the tags string into an array, and also count how many tags the file has
@@ -473,16 +522,12 @@ class datei
             $file["tags"] = stripslashes($file["tags"]);
             $file["size"] = filesize(realpath($file["datei"])) / 1024;
             $file["size"] = round($file["size"]);
-            $file["addedstr"] = date("d.m.y",$file["added"]);
+            $file["addedstr"] = date("d.m.y", $file["added"]);
             $userobj = new user();
             $file["userdata"] = $userobj->getProfile($file["user"]);
 
-
-
             return $file;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -496,6 +541,7 @@ class datei
      */
     function moveFile($file, $target)
     {
+        global $conn;
         $file = (int) $file;
         $target = (int)$target;
         // Get the file
@@ -506,7 +552,7 @@ class datei
         $targetstr = "files/" . CL_CONFIG . "/" . $thefile["project"] . "/" . $thefolder["name"] . "/" . $thefile["name"];
         $rootstr = CL_ROOT . "/" . $thefile["datei"];
         // update database
-        $upd = mysql_query("UPDATE files SET datei = '$targetstr', folder = '$thefolder[ID]' WHERE ID = $thefile[ID]");
+        $upd = $conn->query("UPDATE files SET datei = '$targetstr', folder = '$thefolder[ID]' WHERE ID = $thefile[ID]");
         // move the file physically
         return rename($rootstr, $targetstr);
     }
@@ -521,20 +567,18 @@ class datei
      */
     function getProjectFiles($id, $lim = 25, $folder = "")
     {
+        global $conn;
         $id = (int) $id;
         $lim = (int) $lim;
         $folder = (int) $folder;
 
-        if ($folder > 0)
-        {
+        if ($folder > 0) {
             $fold = "files/" . CL_CONFIG . "/$id/$folder/";
-            $sel = mysql_query("SELECT COUNT(*) FROM files WHERE project = $id AND folder = $folder ORDER BY ID DESC");
+            $sel = $conn->query("SELECT COUNT(*) FROM files WHERE project = $id AND folder = $folder ORDER BY ID DESC");
+        } else {
+            $sel = $conn->query("SELECT COUNT(*) FROM files WHERE project = $id AND folder = 0 ORDER BY ID DESC");
         }
-        else
-        {
-            $sel = mysql_query("SELECT COUNT(*) FROM files WHERE project = $id AND folder = 0 ORDER BY ID DESC");
-        }
-        $num = mysql_fetch_row($sel);
+        $num = $sel->fetch();
         $num = $num[0];
         SmartyPaginate::connect();
         // set items per page
@@ -546,29 +590,20 @@ class datei
 
         $files = array();
 
-        if ($folder > 0)
-        {
+        if ($folder > 0) {
             $sql = "SELECT ID FROM files WHERE project = $id AND folder = $folder ORDER BY  ID DESC LIMIT $start,$lim";
-            $sel2 = mysql_query($sql);
-        }
-        else
-        {
-            $sel2 = mysql_query("SELECT ID FROM files WHERE project = $id AND folder = 0 ORDER BY  ID DESC LIMIT $start,$lim");
-        }
-        while ($file = mysql_fetch_array($sel2))
-        {
-            if (!empty($file))
-            {
+            $sel2 = $conn->query($sql);
+        } else {
+            $sel2 = $conn->query("SELECT ID FROM files WHERE project = $id AND folder = 0 ORDER BY  ID DESC LIMIT $start,$lim");
+        } while ($file = $sel2->fetch()) {
+            if (!empty($file)) {
                 array_push($files, $this->getFile($file["ID"]));
             }
         }
 
-        if (!empty($files))
-        {
+        if (!empty($files)) {
             return $files;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -583,28 +618,24 @@ class datei
      */
     function getAllProjectFiles($id)
     {
+        global $conn;
         $id = (int) $id;
         $lim = (int) $lim;
         $folder = (int) $folder;
 
         $files = array();
 
-        $sel2 = mysql_query("SELECT ID FROM files WHERE project = $id  ORDER BY  ID DESC");
+        $sel2 = $conn->query("SELECT ID FROM files WHERE project = $id  ORDER BY  ID DESC");
 
-        while ($file = mysql_fetch_array($sel2))
-        {
-            if (!empty($file))
-            {
+        while ($file = $sel2->fetch()) {
+            if (!empty($file)) {
                 array_push($files, $this->getFile($file["ID"]));
             }
         }
 
-        if (!empty($files))
-        {
+        if (!empty($files)) {
             return $files;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -635,29 +666,24 @@ class datei
      * @param int $ folder Optional parameter. It holds the ID of the subfolder the file is uploaded to (0 = root directory)
      * @return bool $insid
      */
-    private function add_file($name, $desc, $project, $milestone, $tags, $datei, $type, $title, $folder = 0, $visstr = "")
+    function add_file($name, $desc, $project, $milestone, $tags, $datei, $type, $title = " ", $folder = 0, $visstr = "")
     {
-        $name = mysql_real_escape_string($name);
-        $desc = mysql_real_escape_string($desc);
-        $tags = mysql_real_escape_string($tags);
-        $datei = mysql_real_escape_string($datei);
+        global $conn;
+        if (!$desc) {
+            $desc = " ";
+        }
         $project = (int) $project;
         $milestone = (int) $milestone;
         $folder = (int) $folder;
         $userid = $_SESSION["userid"];
-        $type = mysql_real_escape_string($type);
-        $title = mysql_real_escape_string($title);
         $now = time();
 
-        $ins = mysql_query("INSERT INTO files (`name`,`desc`,`project`,`milestone`,`user`,`tags`,`added`,`datei`,`type`,`title`,`folder`,`visible`) VALUES ('$name','$desc',$project,$milestone,$userid,'$tags','$now','$datei','$type','$title','$folder','$visstr')");
-
-        if ($ins)
-        {
-            $insid = mysql_insert_id();
+        $insStmt = $conn->prepare("INSERT INTO files (`name`, `desc`, `project`, `milestone`, `user`, `tags`, `added`, `datei`, `type`, `title`, `folder`, `visible`) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
+        $ins = $insStmt->execute(array($name, $desc, $project, $milestone, $userid, $tags, $now, $datei, $type, $title, $folder, $visstr));
+        if ($ins) {
+            $insid = $conn->lastInsertId();
             return $insid;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
