@@ -2,16 +2,15 @@
 /**
  * This class provides methods to realize milestones
  *
- * @author Open Dynamics <info@o-dyn.de>
+ * @author Philipp Kiszka <info@o-dyn.de>
  * @name milestone
  * @package Collabtive
- * @version 0.4.5
+ * @version 1.0
  * @link http://www.o-dyn.de
  * @license http://opensource.org/licenses/gpl-license.php GNU General Public License v3 or later
  * @global $mylog
  */
-class milestone
-{
+class milestone {
     private $mylog;
 
     /**
@@ -35,23 +34,18 @@ class milestone
      */
     function add($project, $name, $desc, $end, $status)
     {
-        $project = (int) $project;
-        $name = mysql_real_escape_string($name);
-        $desc = mysql_real_escape_string($desc);
-        $start = time();
+        global $conn;
+
         $end = strtotime($end);
-        $status = (int) $status;
 
-        $ins = mysql_query("INSERT INTO milestones (`project`,`name`,`desc`,`start`,`end`,`status`) VALUES ($project,'$name','$desc','$start','$end',$status)");
+        $insStmt = $conn->prepare("INSERT INTO milestones (`project`,`name`,`desc`,`start`,`end`,`status`) VALUES (?, ?, ?, ?, ?, ?)");
+        $ins = $insStmt->execute(array((int) $project, $name, $desc, time(), $end, (int) $status));
 
-        if ($ins)
-        {
-            $insid = mysql_insert_id();
+        if ($ins) {
+            $insid = $conn->lastInsertId();
             $this->mylog->add($name, 'milestone' , 1, $project);
             return $insid;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -67,24 +61,20 @@ class milestone
      */
     function edit($id, $name, $desc, $end)
     {
+        global $conn;
         $id = (int) $id;
-        $name = mysql_real_escape_string($name);
-        $desc = mysql_real_escape_string($desc);
         $end = strtotime($end);
 
-        $upd = mysql_query("UPDATE milestones SET `name`='$name', `desc`='$desc', `end`='$end' WHERE ID=$id");
-        if ($upd)
-        {
-            $nam = mysql_query("SELECT project,name FROM milestones WHERE ID = $id");
-            $nam = mysql_fetch_row($nam);
+        $updStmt = $conn->prepare("UPDATE milestones SET `name`=?, `desc`=?, `end`=? WHERE ID=?");
+        $upd = $updStmt->execute(array($name, $desc, $end, $id));
+        if ($upd) {
+            $nam = $conn->query("SELECT project,name FROM milestones WHERE ID = $id")->fetch();
             $project = $nam[0];
             $name = $nam[1];
 
             $this->mylog->add($name, 'milestone' , 2, $project);
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -97,22 +87,20 @@ class milestone
      */
     function del($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $nam = mysql_query("SELECT project,name FROM milestones WHERE ID = $id");
-        $del = mysql_query("DELETE FROM milestones WHERE ID = $id");
-        $del1 = mysql_query("DELETE FROM milestones_assigned WHERE milestone = $id");
-        if ($del)
-        {
-            $nam = mysql_fetch_row($nam);
+        $nam = $conn->query("SELECT project,name FROM milestones WHERE ID = $id");
+        $del = $conn->query("DELETE FROM milestones WHERE ID = $id");
+        $del1 = $conn->query("DELETE FROM milestones_assigned WHERE milestone = $id");
+        if ($del) {
+            $nam = $nam->fetch();
             $project = $nam[0];
             $name = $nam[1];
 
             $this->mylog->add($name, 'milestone', 3, $project);
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -125,22 +113,20 @@ class milestone
      */
     function open($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $upd = mysql_query("UPDATE milestones SET status = 1 WHERE ID = $id");
+        $upd = $conn->query("UPDATE milestones SET status = 1 WHERE ID = $id");
 
-        if ($upd)
-        {
-            $nam = mysql_query("SELECT project,name FROM milestones WHERE ID = $id");
-            $nam = mysql_fetch_row($nam);
+        if ($upd) {
+            $nam = $conn->query("SELECT project,name FROM milestones WHERE ID = $id");
+            $nam = $nam->fetch();
             $project = $nam[0];
             $name = $nam[1];
 
             $this->mylog->add($name, 'milestone', 4, $project);
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -153,36 +139,31 @@ class milestone
      */
     function close($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $upd = mysql_query("UPDATE milestones SET status = 0 WHERE ID = $id");
+        $upd = $conn->query("UPDATE milestones SET status = 0 WHERE ID = $id");
         $tasklists = $this->getMilestoneTasklists($id);
-        if (!empty($tasklists))
-        {
-            foreach ($tasklists as $tasklist)
-            {
+        if (!empty($tasklists)) {
+            foreach ($tasklists as $tasklist) {
                 $tl = new tasklist();
                 $tasks = $tl->getTasksFromList($tasklist[ID]);
-                foreach ($tasks as $task)
-                {
-                    $close_task = mysql_query("UPDATE tasks SET status = 0 WHERE ID = $task[ID]");
+                foreach ($tasks as $task) {
+                    $close_task = $conn->query("UPDATE tasks SET status = 0 WHERE ID = $task[ID]");
                 }
-                $close_tasklist = mysql_query("UPDATE tasklist SET status = 0 WHERE ID = $tasklist[ID]");
+                $close_tasklist = $conn->query("UPDATE tasklist SET status = 0 WHERE ID = $tasklist[ID]");
             }
         }
 
-        if ($upd)
-        {
-            $nam = mysql_query("SELECT project,name FROM milestones WHERE ID = $id");
-            $nam = mysql_fetch_row($nam);
+        if ($upd) {
+            $nam = $conn->query("SELECT project,name FROM milestones WHERE ID = $id");
+            $nam = $nam->fetch();
             $project = $nam[0];
             $name = $nam[1];
 
             $this->mylog->add($name, 'milestone', 5, $project);
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -196,22 +177,20 @@ class milestone
      */
     function assign($milestone, $user)
     {
+        global $conn;
         $milestone = (int) $milestone;
         $user = (int) $user;
 
-        $upd = mysql_query("INSERT INTO milestones_assigned (NULL,$user,$milestone)");
-        if ($upd)
-        {
-            $nam = mysql_query("SELECT project,name FROM milestones WHERE ID = $id");
-            $nam = mysql_fetch_row($nam);
+        $upd = $conn->query("INSERT INTO milestones_assigned (NULL,$user,$milestone)");
+        if ($upd) {
+            $nam = $conn->query("SELECT project,name FROM milestones WHERE ID = $id");
+            $nam = $nam->fetch();
             $project = $nam[0];
             $name = $nam[1];
 
             $this->mylog->add($name, 'milestone', 6, $project);
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -225,22 +204,20 @@ class milestone
      */
     function deassign($milestone, $user)
     {
+        global $conn;
         $milestone = (int) $milestone;
         $user = (int) $user;
 
-        $upd = mysql_query("DELETE FROM milestones_assigned WHERE user = $user AND milestone = $milestone");
-        if ($upd)
-        {
-            $nam = mysql_query("SELECT project,name FROM milestones WHERE ID = $id");
-            $nam = mysql_fetch_row($nam);
+        $upd = $conn->query("DELETE FROM milestones_assigned WHERE user = $user AND milestone = $milestone");
+        if ($upd) {
+            $nam = $conn->query("SELECT project,name FROM milestones WHERE ID = $id");
+            $nam = $nam->fetch();
             $project = $nam[0];
             $name = $nam[1];
 
             $this->mylog->add($name, 'milestone', 7, $project);
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -253,13 +230,13 @@ class milestone
      */
     function getMilestone($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $sel = mysql_query("SELECT * FROM milestones WHERE ID = $id");
-        $milestone = mysql_fetch_array($sel);
+        $sel = $conn->query("SELECT * FROM milestones WHERE ID = $id");
+        $milestone = $sel->fetch();
 
-        if (!empty($milestone))
-        {
+        if (!empty($milestone)) {
             $endstring = date(CL_DATEFORMAT, $milestone["end"]);
             $milestone["endstring"] = $endstring;
             $milestone["fend"] = $endstring;
@@ -270,8 +247,8 @@ class milestone
             $milestone["name"] = stripslashes($milestone["name"]);
             $milestone["desc"] = stripslashes($milestone["desc"]);
 
-            $psel = mysql_query("SELECT name FROM projekte WHERE ID = $milestone[project]");
-            $pname = mysql_fetch_row($psel);
+            $psel = $conn->query("SELECT name FROM projekte WHERE ID = $milestone[project]");
+            $pname = $psel->fetch();
             $pname = $pname[0];
             $milestone["pname"] = $pname;
             $milestone["pname"] = stripslashes($milestone["pname"]);
@@ -287,9 +264,7 @@ class milestone
             $milestone["messages"] = $messages;
 
             return $milestone;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -298,30 +273,27 @@ class milestone
      * Return the latest milestones
      *
      * @param int $status Status (0 = finished, 1 = open)
-     * @param int $num Number of milestones to return
+     * @param int $lim Number of milestones to return
      * @return array $milestones Details of the milestones
      */
-    function getMilestones($status = 1, $num = 10)
+    function getMilestones($status = 1, $lim = 100)
     {
+        global $conn;
         $status = (int) $status;
-        $num = (int) $num;
+        $lim = (int) $lim;
 
         $milestones = array();
 
-        $sel = mysql_query("SELECT ID FROM milestones WHERE `status`=$status LIMIT $num");
+        $sel = $conn->query("SELECT ID FROM milestones WHERE `status`=$status LIMIT $lim");
 
-        while ($milestone = mysql_fetch_array($sel))
-        {
+        while ($milestone = $sel->fetch()) {
             $themilestone = $this->getMilestone($milestone["ID"]);
             array_push($milestones, $themilestone);
         }
 
-        if (!empty($milestones))
-        {
+        if (!empty($milestones)) {
             return $milestones;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -334,23 +306,20 @@ class milestone
      */
     function getDoneProjectMilestones($project)
     {
+        global $conn;
         $project = (int) $project;
 
-        $sel = mysql_query("SELECT ID FROM milestones WHERE project = $project AND status = 0 ORDER BY ID ASC");
+        $sel = $conn->query("SELECT ID FROM milestones WHERE project = $project AND status = 0 ORDER BY ID ASC");
         $stones = array();
 
-        while ($milestone = mysql_fetch_array($sel))
-        {
+        while ($milestone = $sel->fetch()) {
             $themilestone = $this->getMilestone($milestone["ID"]);
             array_push($stones, $themilestone);
         }
 
-        if (!empty($stones))
-        {
+        if (!empty($stones)) {
             return $stones;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -362,8 +331,9 @@ class milestone
      * @param int $lim Number of milestones to return
      * @return array $milestones Dateils of the late milestones
      */
-    function getLateProjectMilestones($project, $lim = 10)
+    function getLateProjectMilestones($project, $lim = 100)
     {
+        global $conn;
         $project = (int) $project;
         $lim = (int) $lim;
 
@@ -373,22 +343,17 @@ class milestone
 
         $sql = "SELECT ID FROM milestones WHERE project = $project AND end < $now AND status = 1 ORDER BY end ASC LIMIT $lim";
 
-        $sel1 = mysql_query($sql);
-        while ($milestone = mysql_fetch_array($sel1))
-        {
-            if (!empty($milestone))
-            {
+        $sel1 = $conn->query($sql);
+        while ($milestone = $sel1->fetch()) {
+            if (!empty($milestone)) {
                 $themilestone = $this->getMilestone($milestone["ID"]);
                 array_push($milestones, $themilestone);
             }
         }
 
-        if (!empty($milestones))
-        {
+        if (!empty($milestones)) {
             return $milestones;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -400,8 +365,9 @@ class milestone
      * @param int $lim Number of milestones to return
      * @return array $milestones Details of the open milestones
      */
-    function getAllProjectMilestones($project, $lim = 10)
+    function getAllProjectMilestones($project, $lim = 100)
     {
+        global $conn;
         $project = (int) $project;
         $lim = (int) $lim;
 
@@ -410,22 +376,17 @@ class milestone
         $milestones = array();
         $sql = "SELECT ID FROM milestones WHERE project = $project AND status = 1 ORDER BY end ASC LIMIT $lim";
 
-        $sel1 = mysql_query($sql);
-        while ($milestone = mysql_fetch_array($sel1))
-        {
-            if (!empty($milestone))
-            {
+        $sel1 = $conn->query($sql);
+        while ($milestone = $sel1->fetch()) {
+            if (!empty($milestone)) {
                 $themilestone = $this->getMilestone($milestone["ID"]);
                 array_push($milestones, $themilestone);
             }
         }
 
-        if (!empty($milestones))
-        {
+        if (!empty($milestones)) {
             return $milestones;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -437,32 +398,29 @@ class milestone
      * @param int $lim Number of milestones to return
      * @return array $milestones Details of the milestones
      */
-    function getProjectMilestones($project, $lim = -1)
+    function getProjectMilestones($project, $lim = 100)
     {
+        global $conn;
         $project = (int) $project;
         $lim = (int) $lim;
 
         $now = time();
         $milestones = array();
         $sql = "SELECT * FROM milestones WHERE project = $project AND end > $now AND status = 1 ORDER BY end ASC";
-        
+
         if ($lim > 0) {
-        	$sql .= " LIMIT $lim";
+            $sql .= " LIMIT $lim";
         }
 
-        $sel1 = mysql_query($sql);
-        while ($milestone = mysql_fetch_array($sel1))
-        {
+        $sel1 = $conn->query($sql);
+        while ($milestone = $sel1->fetch()) {
             $themilestone = $this->getMilestone($milestone["ID"]);
             array_push($milestones, $themilestone);
         }
 
-        if (!empty($milestones))
-        {
+        if (!empty($milestones)) {
             return $milestones;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -475,8 +433,9 @@ class milestone
      * @return array $milestones Details of the milestones
      */
 
-    function getTodayProjectMilestones($project, $lim = 10)
+    function getTodayProjectMilestones($project, $lim = 100)
     {
+        global $conn;
         $project = (int) $project;
         $lim = (int) $lim;
 
@@ -484,19 +443,15 @@ class milestone
         $now = strtotime($tod);
         $milestones = array();
 
-        $sel1 = mysql_query("SELECT * FROM milestones WHERE project = $project AND end = '$now' AND status = 1 ORDER BY end ASC LIMIT $lim");
-        while ($milestone = mysql_fetch_array($sel1))
-        {
+        $sel1 = $conn->query("SELECT * FROM milestones WHERE project = $project AND end = '$now' AND status = 1 ORDER BY end ASC LIMIT $lim");
+        while ($milestone = $sel1->fetch()) {
             $themilestone = $this->getMilestone($milestone["ID"]);
             array_push($milestones, $themilestone);
         }
 
-        if (!empty($milestones))
-        {
+        if (!empty($milestones)) {
             return $milestones;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -512,15 +467,13 @@ class milestone
      */
     function getTodayMilestones($m, $y, $d, $project = 0)
     {
+        global $conn;
         $m = (int) $m;
         $y = (int) $y;
 
-        if ($m > 9)
-        {
+        if ($m > 9) {
             $startdate = date($d . "." . $m . "." . $y);
-        }
-        else
-        {
+        } else {
             $startdate = date($d . ".0" . $m . "." . $y);
         }
         $starttime = strtotime($startdate);
@@ -528,27 +481,18 @@ class milestone
 
         $timeline = array();
 
-        if ($project > 0)
-        {
-            $sel1 = mysql_query("SELECT * FROM milestones WHERE project =  $project AND status=1 AND end = '$starttime'");
-        }
-        else
-        {
-			$sel1 = mysql_query("SELECT milestones.*,projekte_assigned.user,projekte.name AS pname FROM milestones,projekte_assigned,projekte WHERE milestones.project = projekte_assigned.projekt AND milestones.project = projekte.ID HAVING projekte_assigned.user = $user AND status=1 AND end = '$starttime'");
-        }
-
-        while ($stone = mysql_fetch_array($sel1))
-        {
+        if ($project > 0) {
+            $sel1 = $conn->query("SELECT * FROM milestones WHERE project =  $project AND status=1 AND end = '$starttime'");
+        } else {
+            $sel1 = $conn->query("SELECT milestones.*,projekte_assigned.user,projekte.name AS pname FROM milestones,projekte_assigned,projekte WHERE milestones.project = projekte_assigned.projekt AND milestones.project = projekte.ID HAVING projekte_assigned.user = $user AND status=1 AND end = '$starttime'");
+        } while ($stone = $sel1->fetch()) {
             $stone["daysleft"] = $this->getDaysLeft($stone["end"]);
             array_push($timeline, $stone);
         }
 
-        if (!empty($timeline))
-        {
+        if (!empty($timeline)) {
             return $timeline;
-        }
-        else
-        {
+        } else {
             return array();
         }
     }
@@ -561,40 +505,35 @@ class milestone
      */
     private function getMilestoneTasklists($milestone)
     {
+        global $conn;
         $milestone = (int) $milestone;
 
-        $sel = mysql_query("SELECT * FROM tasklist WHERE milestone = $milestone AND status = 1");
+        $sel = $conn->query("SELECT * FROM tasklist WHERE milestone = $milestone AND status = 1");
         $lists = array();
-        if ($milestone)
-        {
-            while ($list = mysql_fetch_array($sel))
-            {
+        if ($milestone) {
+            while ($list = $sel->fetch()) {
                 $list["name"] = stripslashes($list["name"]);
                 $list["desc"] = stripslashes($list["desc"]);
                 array_push($lists, $list);
             }
         }
-        if (!empty($lists))
-        {
+        if (!empty($lists)) {
             return $lists;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
 
     private function getMilestoneMessages($milestone)
     {
+        global $conn;
         $milestone = (int) $milestone;
-        $sel = mysql_query("SELECT ID,title FROM messages WHERE milestone = $milestone");
+        $sel = $conn->query("SELECT ID,title FROM messages WHERE milestone = $milestone");
         $msgs = array();
-        while ($msg = mysql_fetch_array($sel))
-        {
+        while ($msg = $sel->fetch()) {
             array_push($msgs, $msg);
         }
-        if (!empty($msgs))
-        {
+        if (!empty($msgs)) {
             return $msgs;
         }
     }
@@ -625,22 +564,17 @@ class milestone
     {
         $cou = 0;
 
-        if ($milestones)
-        {
-            foreach($milestones as $stone)
-            {
+        if ($milestones) {
+            foreach($milestones as $stone) {
                 $datetime = date(CL_DATEFORMAT, $stone[5]);
                 $milestones[$cou]["due"] = $datetime;
                 $cou = $cou + 1;
             }
         }
 
-        if (!empty($milestones))
-        {
+        if (!empty($milestones)) {
             return $milestones;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
