@@ -32,21 +32,18 @@ class project {
      */
     function add($name, $desc, $end, $budget, $assignme = 0)
     {
-        $name = mysql_real_escape_string($name);
-        $desc = mysql_real_escape_string($desc);
-        $end = mysql_real_escape_string($end);
-        $assignme = (int) $assignme;
-        $budget = (float) $budget;
+        global $conn;
 
         if ($end > 0) {
             $end = strtotime($end);
         }
         $now = time();
 
-        $ins1 = mysql_query("INSERT INTO projekte (`name`, `desc`, `end`, `start`, `status`, `budget`) VALUES ('$name','$desc','$end','$now',1,'$budget')");
+        $ins1Stmt = $conn->prepare("INSERT INTO projekte (`name`, `desc`, `end`, `start`, `status`, `budget`) VALUES (?,?,?,?,1,?)");
+        $ins1 = $ins1Stmt->execute(array($name, $desc, $end, $now, (float) $budget));
 
-        $insid = mysql_insert_id();
-        if ($assignme == 1) {
+        $insid = $conn->lastInsertId();
+        if ((int) $assignme == 1) {
             $uid = $_SESSION['userid'];
             $this->assign($uid, $insid);
         }
@@ -70,9 +67,7 @@ class project {
      */
     function AddFromBasecamp($name, $desc, $start, $status = 1)
     {
-        $name = mysql_real_escape_string($name);
-        $desc = mysql_real_escape_string($desc);
-        $start = mysql_real_escape_string($start);
+        global $conn;
         $id = (int) $id;
         $status = (int) $status;
 
@@ -80,9 +75,10 @@ class project {
         $tod = date("d.m.Y");
         $now = strtotime($tod . " +1week");
 
-        $ins1 = mysql_query("INSERT INTO projekte (`name`, `desc`,`end`, `start`, `status`) VALUES ('$name','$desc','$now','$start','$status')");
+        $ins1Stmt = $conn->prepare("INSERT INTO projekte (`name`, `desc`,`end`, `start`, `status`) VALUES (?, ?, ?, ?, ?)");
+        $ins1 = $ins1Stmt->execute(array($name, $desc, $now, $start, $status));
 
-        $insid = mysql_insert_id();
+        $insid = $conn->lastInsertId();
 
         if ($ins1) {
             mkdir(CL_ROOT . "/files/" . CL_CONFIG . "/$insid/", 0777);
@@ -104,15 +100,13 @@ class project {
      */
     function edit($id, $name, $desc, $end, $budget)
     {
-        $id = mysql_real_escape_string($id);
-        $name = mysql_real_escape_string($name);
-        $desc = mysql_real_escape_string($desc);
-        $end = mysql_real_escape_string($end);
+        global $conn;
         $end = strtotime($end);
         $id = (int) $id;
         $budget = (float) $budget;
 
-        $upd = mysql_query("UPDATE projekte SET name='$name',`desc`='$desc',`end`='$end',budget=$budget WHERE ID = $id");
+        $updStmt = $conn->prepare("UPDATE projekte SET name=?,`desc`=?,`end`=?,budget=? WHERE ID = ?");
+        $upd = $updStmt->execute(array($name, $desc, $end, $budget, $id));
 
         if ($upd) {
             $this->mylog->add($name, 'projekt' , 2, $id);
@@ -130,15 +124,15 @@ class project {
      */
     function del($id)
     {
+        global $conn;
         $userid = $_SESSION["userid"];
-        $id = mysql_real_escape_string($id);
         $id = (int) $id;
         // Delete assignments of tasks of this project to users
         $task = new task();
         $tasks = $task->getProjectTasks($id);
         if (!empty($tasks)) {
             foreach ($tasks as $tas) {
-                $del_taskassign = mysql_query("DELETE FROM tasks_assigned WHERE task = $tas[ID]");
+                $del_taskassign = $conn->query("DELETE FROM tasks_assigned WHERE task = $tas[ID]");
             }
         }
         // Delete files and the assignments of these files to the messages they were attached to
@@ -150,15 +144,15 @@ class project {
             }
         }
 
-        $del_messages = mysql_query("DELETE FROM messages WHERE project = $id");
-        $del_milestones = mysql_query("DELETE FROM milestones WHERE project = $id");
-        $del_projectassignments = mysql_query("DELETE FROM projekte_assigned WHERE projekt = $id");
-        $del_tasklists = mysql_query("DELETE FROM tasklist WHERE project = $id");
-        $del_tasks = mysql_query("DELETE FROM tasks WHERE project = $id");
-        $del_timetracker = mysql_query("DELETE FROM timetracker WHERE project = $id");
+        $del_messages = $conn->query("DELETE FROM messages WHERE project = $id");
+        $del_milestones = $conn->query("DELETE FROM milestones WHERE project = $id");
+        $del_projectassignments = $conn->query("DELETE FROM projekte_assigned WHERE projekt = $id");
+        $del_tasklists = $conn->query("DELETE FROM tasklist WHERE project = $id");
+        $del_tasks = $conn->query("DELETE FROM tasks WHERE project = $id");
+        $del_timetracker = $conn->query("DELETE FROM timetracker WHERE project = $id");
 
-        $del_logentries = mysql_query("DELETE FROM log WHERE project = $id");
-        $del = mysql_query("DELETE FROM projekte WHERE ID = $id");
+        $del_logentries = $conn->query("DELETE FROM log WHERE project = $id");
+        $del = $conn->query("DELETE FROM projekte WHERE ID = $id");
 
         delete_directory(CL_ROOT . "/files/" . CL_CONFIG . "/$id");
         if ($del) {
@@ -177,13 +171,12 @@ class project {
      */
     function open($id)
     {
-        $id = mysql_real_escape_string($id);
+        global $conn;
         $id = (int) $id;
 
-        $upd = mysql_query("UPDATE projekte SET status=1 WHERE ID = $id");
+        $upd = $conn->query("UPDATE projekte SET status=1 WHERE ID = $id");
         if ($upd) {
-            $nam = mysql_query("SELECT name FROM projekte WHERE ID = $id");
-            $nam = mysql_fetch_row($nam);
+            $nam = $conn->query("SELECT name FROM projekte WHERE ID = $id")->fetch();
             $nam = $nam[0];
             $this->mylog->add($nam, 'projekt', 4, $id);
             return true;
@@ -200,14 +193,14 @@ class project {
      */
     function close($id)
     {
-        $id = mysql_real_escape_string($id);
+        global $conn;
         $id = (int) $id;
 
         $mile = new milestone();
         $milestones = $mile->getAllProjectMilestones($id, 100000);
         if (!empty($milestones)) {
             foreach ($milestones as $miles) {
-                $close_milestones = mysql_query("UPDATE milestones SET status = 0 WHERE ID = $miles[ID]");
+                $close_milestones = $conn->query("UPDATE milestones SET status = 0 WHERE ID = $miles[ID]");
             }
         }
 
@@ -215,7 +208,7 @@ class project {
         $tasks = $task->getProjectTasks($id);
         if (!empty($tasks)) {
             foreach ($tasks as $tas) {
-                $close_tasks = mysql_query("UPDATE tasks SET status = 0 WHERE ID = $tas[ID]");
+                $close_tasks = $conn->query("UPDATE tasks SET status = 0 WHERE ID = $tas[ID]");
             }
         }
 
@@ -223,14 +216,13 @@ class project {
         $tasklists = $tasklist->getProjectTasklists($id);
         if (!empty($tasklists)) {
             foreach ($tasklists as $tl) {
-                $close_tasklists = mysql_query("UPDATE tasklist SET status = 0 WHERE ID = $tl[ID]");
+                $close_tasklists = $conn->query("UPDATE tasklist SET status = 0 WHERE ID = $tl[ID]");
             }
         }
 
-        $upd = mysql_query("UPDATE projekte SET status=0 WHERE ID = $id");
+        $upd = $conn->query("UPDATE projekte SET status=0 WHERE ID = $id");
         if ($upd) {
-            $nam = mysql_query("SELECT name FROM projekte WHERE ID = $id");
-            $nam = mysql_fetch_row($nam);
+            $nam = $conn->query("SELECT name FROM projekte WHERE ID = $id")->fetch();
             $nam = $nam[0];
             $this->mylog->add($nam, 'projekt', 5, $id);
             return true;
@@ -248,13 +240,14 @@ class project {
      */
     function assign($user, $id)
     {
-        $user = mysql_real_escape_string($user);
-        $id = mysql_real_escape_string($id);
-        $user = (int) $user;
-        $id = (int) $id;
+        global $conn;
 
-        $ins = mysql_query("INSERT INTO projekte_assigned (user,projekt) VALUES ($user,$id)");
+        $insStmt = $conn->prepare("INSERT INTO projekte_assigned (user,projekt) VALUES (?,?)");
+        $ins = $insStmt->execute(array((int) $user, (int) $id));
         if ($ins) {
+            $userObj = new user();
+            $user = $userObj->getProfile($user);
+            $this->mylog->add($user["name"], 'user', 6, $id);
             return true;
         } else {
             return false;
@@ -264,43 +257,47 @@ class project {
     /**
      * Entfernt ein Projekt aus der Zuweisung an ein bestimmtes Mitglied
      *
-     * @param int $user Eindeutige Mitgliedsnummer
-     * @param int $id Eindeutige Projektnummer
+     * @param int $user User ID
+     * @param int $id Project ID
      * @return bool
      */
     function deassign($user, $id)
     {
-        $user = mysql_real_escape_string($user);
-        $id = mysql_real_escape_string($id);
-        $user = (int) $user;
-        $id = (int) $id;
+        global $conn;
 
-        $sql = "DELETE FROM projekte_assigned WHERE user = $user AND projekt = $id";
+        $sqlStmt = $conn->prepare("DELETE FROM projekte_assigned WHERE user = ? AND projekt = ?");
 
         $milestone = new milestone();
         $donemiles = $milestone->getDoneProjectMilestones($id);
         if (!empty($donemiles)) {
+            $sql1Stmt = $conn->prepare("DELETE FROM milestones_assigned WHERE user = ? AND milestone = ?");
             foreach ($donemiles as $dm) {
-                $sql1 = mysql_query("DELETE FROM milestones_assigned WHERE user = $user AND milestone = $dm[ID]");
+                $sql1 = $sql1Stmt->execute(array((int) $user, $dm['ID']));
             }
         }
+
         $openmiles = $milestone->getAllProjectMilestones($id, 100000);
         if (!empty($openmiles)) {
+            $sql2Stmt = $conn->prepare("DELETE FROM milestones_assigned WHERE user = ? AND milestone = ?");
             foreach ($openmiles as $om) {
-                $sql2 = mysql_query("DELETE FROM milestones_assigned WHERE user = $user AND milestone = $om[ID]");
+                $sql2 = $sql2Stmt->execute(array((int) $user, $om['ID']));
             }
         }
 
         $task = new task();
         $tasks = $task->getProjectTasks($id);
         if (!empty($tasks)) {
+            $sql3Stmt = $conn->prepare("DELETE FROM tasks_assigned WHERE user = ? AND task = ?");
             foreach ($tasks as $t) {
-                $sql3 = mysql_query("DELETE FROM tasks_assigned WHERE user = $user AND task = $t[ID]");
+                $sql3 = $sql3Stmt->execute(array((int) $user, $t['ID']));
             }
         }
 
-        $del = mysql_query($sql);
+        $del = $sqlStmt->execute(array((int) $user, (int) $id));
         if ($del) {
+            $userObj = new user();
+            $user = $userObj->getProfile($user);
+            $this->mylog->add($user["name"], 'user', 7, $id);
             return true;
         } else {
             return false;
@@ -316,10 +313,13 @@ class project {
      */
     function getProject($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $sel = mysql_query("SELECT * FROM projekte WHERE ID = $id");
-        $project = mysql_fetch_array($sel, MYSQL_ASSOC);
+        $sel = $conn->prepare("SELECT * FROM projekte WHERE ID = ?");
+        $selStmt = $sel->execute(array($id));
+
+		$project = $sel->fetch();
 
         if (!empty($project)) {
             if ($project["end"]) {
@@ -353,15 +353,17 @@ class project {
      */
     function getProjects($status = 1, $lim = 10)
     {
-        $status = mysql_real_escape_string($status);
-        $lim = mysql_real_escape_string($lim);
+        global $conn;
+
         $status = (int) $status;
         $lim = (int) $lim;
 
         $projekte = array();
-        $sel = mysql_query("SELECT ID FROM projekte WHERE `status`=$status ORDER BY end ASC LIMIT $lim");
 
-        while ($projekt = mysql_fetch_array($sel)) {
+        $sel = $conn->prepare("SELECT `ID` FROM projekte WHERE `status`= ? ORDER BY `end` ASC LIMIT $lim");
+		$selStmt = $sel->execute(array($status));
+
+        while ($projekt = $sel->fetch()) {
             $project = $this->getProject($projekt["ID"]);
             array_push($projekte, $project);
         }
@@ -374,7 +376,7 @@ class project {
     }
 
     /**
-     * Listet alle einem Mitglied zugewiesenen Projekte auf
+     * Lists all projects assigned to a given member ordered by due date ascending
      *
      * @param int $user Eindeutige Mitgliedsnummer
      * @param int $status Bearbeitungsstatus von Projekten (1 = offenes Projekt)
@@ -382,16 +384,16 @@ class project {
      */
     function getMyProjects($user, $status = 1)
     {
-        $user = mysql_real_escape_string($user);
-        $status = mysql_real_escape_string($status);
-        $user = (int) $user;
-        $status = (int) $status;
+        global $conn;
 
         $myprojekte = array();
-        $sel = mysql_query("SELECT projekt FROM projekte_assigned WHERE user = $user ORDER BY ID ASC");
+        $user = (int) $user;
 
-        while ($projs = mysql_fetch_row($sel)) {
-            $projekt = mysql_fetch_array(mysql_query("SELECT ID FROM projekte WHERE ID = $projs[0] AND status=$status"), MYSQL_ASSOC);
+        $sel = $conn->prepare("SELECT projekt FROM projekte_assigned WHERE user = ? ORDER BY ID ASC");
+        $selStmt = $sel->execute(array($user));
+
+        while ($projs = $sel->fetch()) {
+            $projekt = $conn->query("SELECT ID FROM projekte WHERE ID = " . $projs[0] . " AND status={$conn->quote((int) $status)}")->fetch();
             if ($projekt) {
                 $project = $this->getProject($projekt["ID"]);
                 array_push($myprojekte, $project);
@@ -399,6 +401,13 @@ class project {
         }
 
         if (!empty($myprojekte)) {
+            // Sort projects by due date ascending
+            $date = array();
+            foreach ($myprojekte as $key => $row) {
+                $date[$key] = $row['end'];
+            }
+            array_multisort($date, SORT_ASC, $myprojekte);
+
             return $myprojekte;
         } else {
             return false;
@@ -413,15 +422,16 @@ class project {
      */
     function getMyProjectIds($user)
     {
-        $user = mysql_real_escape_string($user);
-        $user = (int) $user;
+        global $conn;
 
         $myprojekte = array();
-        $sel = mysql_query("SELECT projekt FROM projekte_assigned WHERE user = $user ORDER BY end ASC");
+        $sel = $conn->prepare("SELECT projekt FROM projekte_assigned WHERE user = ? ORDER BY end ASC");
+        $selStmt = $sel->execute(array($user));
+
         if ($sel) {
-            while ($projs = mysql_fetch_row($sel)) {
-                $sel2 = mysql_query("SELECT ID FROM projekte WHERE ID = $projs[0]");
-                $projekt = mysql_fetch_array($sel2);
+            while ($projs = $sel->fetch()) {
+                $sel2 = $conn->query("SELECT ID FROM projekte WHERE ID = " . $projs[0]);
+                $projekt = $sel2->fetch();
                 if ($projekt) {
                     array_push($myprojekte, $projekt);
                 }
@@ -443,6 +453,7 @@ class project {
      */
     function getProjectMembers($project, $lim = 10, $paginate = true)
     {
+        global $conn;
         $project = (int) $project;
         $lim = (int) $lim;
         $project = (int) $project;
@@ -451,7 +462,7 @@ class project {
         $members = array();
 
         if ($paginate) {
-            $num = mysql_fetch_row(mysql_query("SELECT COUNT(*) FROM projekte_assigned WHERE projekt = $project"));
+            $num = $conn->query("SELECT COUNT(*) FROM projekte_assigned WHERE projekt = $project")->fetch();
             $num = $num[0];
             $lim = (int)$lim;
             SmartyPaginate::connect();
@@ -464,10 +475,10 @@ class project {
         } else {
             $start = 0;
         }
-        $sel1 = mysql_query("SELECT user FROM projekte_assigned WHERE projekt = $project LIMIT $start,$lim");
+        $sel1 = $conn->query("SELECT user FROM projekte_assigned WHERE projekt = $project LIMIT $start,$lim");
 
         $usr = new user();
-        while ($user = mysql_fetch_array($sel1)) {
+        while ($user = $sel1->fetch()) {
             $theuser = $usr->getProfile($user[0]);
             array_push($members, $theuser);
         }
@@ -481,8 +492,9 @@ class project {
 
     function countMembers($project)
     {
+        global $conn;
         $project = (int) $project;
-        $num = mysql_fetch_row(mysql_query("SELECT COUNT(*) FROM projekte_assigned WHERE projekt = $project"));
+        $num = $conn->query("SELECT COUNT(*) FROM projekte_assigned WHERE projekt = $project")->fetch();
         return $num[0];
     }
 
@@ -494,15 +506,13 @@ class project {
      */
     function getProgress($project)
     {
-        $project = mysql_real_escape_string($project);
+        global $conn;
         $project = (int) $project;
 
-        $otasks = mysql_query("SELECT COUNT(*) FROM tasks WHERE project = $project AND status = 1");
-        $otasks = mysql_fetch_row($otasks);
+        $otasks = $conn->query("SELECT COUNT(*) FROM tasks WHERE project = $project AND status = 1")->fetch();
         $otasks = $otasks[0];
 
-        $clotasks = mysql_query("SELECT COUNT(*) FROM tasks WHERE project = $project AND status = 0");
-        $clotasks = mysql_fetch_row($clotasks);
+        $clotasks = $conn->query("SELECT COUNT(*) FROM tasks WHERE project = $project AND status = 0")->fetch();
         $clotasks = $clotasks[0];
 
         $totaltasks = $otasks + $clotasks;
@@ -517,11 +527,14 @@ class project {
 
     function getProjectFolders($project)
     {
+        global $conn;
         $project = (int) $project;
-        $sel = mysql_query("SELECT * FROM projectfolders WHERE project = $project");
+
+        $sel = $conn->prepare("SELECT * FROM projectfolders WHERE project = ?");
+		$selStmt = $sel->execute(array($project));
 
         $folders = array();
-        while ($folder = mysql_fetch_array($sel)) {
+        while ($folder = $sel->fetch()) {
             array_push($folders, $folder);
         }
 
@@ -545,80 +558,7 @@ class project {
         return floor($diff / 86400);
     }
 
-    /**
-     * Copy a project
-     * by: Daniel Tlach <danaketh@gmail.com>,
-     * Philipp Kiszka <info@o-dyn.de>
-     *
-     * @param int $id ID of project to copy
-     * @return int $insid New project's ID
-     */
-    function makecopy($id)
-    {
-        // copy project
-        $q = mysql_query("INSERT INTO projekte (`name`, `desc`, `end`, `start`, `status`, `budget`) SELECT `name`, `desc`, `end`, `start`, `status`, `budget` FROM projekte WHERE ID = " . (int)$id);
 
-        $insid = mysql_insert_id();
-        $uid = $_SESSION['userid'];
-        $this->assign($uid, $insid);
-
-        $milesobj = new milestone();
-        $objtasklist = new tasklist();
-        $objtask = new task();
-
-        if ($q) {
-            $pname = $this->getProject($insid);
-            $name = $pname["name"] . " Copy";
-            mysql_query("UPDATE projekte SET `name` = '$name' WHERE ID = " . $insid . " LIMIT 1");
-            // now copy the milestones
-            $miles = $milesobj->getAllProjectMilestones($id);
-            if (!empty($miles)) {
-                // go through the milestones
-                foreach ($miles as $ms) {
-                    // copy milestone
-                    $msid = $milesobj->add($insid, $ms["name"] , $ms["desc"] , $ms["end"] , 1);
-                    // get all tasklists for milestone
-                    $qb = mysql_query("SELECT * FROM tasklist WHERE project = $id AND milestone = $ms[ID]");
-                    if ($qb) {
-                        // go through the tasklists
-                        while ($tl = mysql_fetch_array($qb)) {
-                            // copy tasklist
-                            $tlid = $objtasklist->add_liste($insid, $tl["name"] , $tl["desc"], 0, $msid);
-                            // get tasks for the tasklist
-                            $tasks = $objtasklist->getTasksFromList($tl["ID"]);
-                            if (!empty($tasks)) {
-                                foreach ($tasks as $task) {
-                                    $taskobj->add($task["end"], $task["title"] , $task["text"] , $tlid , $uid , $insid);
-                                } // tasks END
-                            }
-                        } // tasklists END
-                    }
-                } // milestones END
-            }
-            // get all tasklists and tasks that do not belong to a milestone
-            $qb = mysql_query("SELECT * FROM tasklist WHERE project = $id AND milestone = 0");
-            if ($qb) {
-                // go through the tasklists
-                while ($tl = mysql_fetch_array($qb)) {
-                    // copy tasklist
-                    $tlid = $objtasklist->add_liste($insid, $tl["name"] , $tl["desc"], 0, $msid);
-                    // get tasks for the tasklist
-                    $tasks = $objtasklist->getTasksFromList($tl["ID"]);
-                    if (!empty($tasks)) {
-                        foreach ($tasks as $task) {
-                            $taskobj->add($task["end"], $task["title"] , $task["text"] , $tlid , $uid , $insid);
-                        } // tasks END
-                    }
-                } // tasklists END
-            }
-
-            mkdir(CL_ROOT . "/files/" . CL_CONFIG . "/$insid/", 0777);
-            $this->mylog->add($name, 'projekt', 1, $insid);
-            return $insid;
-        } else {
-            return false;
-        }
-    }
 }
 
 ?>
\ No newline at end of file
