@@ -8,12 +8,11 @@
  * @version 0.5.5
  * @link http://www.o-dyn.de
  * @license http://opensource.org/licenses/gpl-license.php GNU General Public License v3 or later
- * @global $mylog
  */
-class task
-{
+
+class task {
     private $mylog;
-    private $plugins;
+
 
     /**
      * Constructor
@@ -22,7 +21,6 @@ class task
     function __construct()
     {
         $this->mylog = new mylog;
-
     }
 
     /**
@@ -38,32 +36,27 @@ class task
      */
     function add($end, $title, $text, $liste, $project)
     {
-        $end = mysql_real_escape_string($end);
-        $title = mysql_real_escape_string($title);
-        $text = mysql_real_escape_string($text);
+        global $conn;
         $liste = (int) $liste;
         $project = (int) $project;
 
         $end_fin = strtotime($end);
 
-        if (empty($end_fin))
-        {
+        if (empty($end_fin)) {
             $end_fin = $end;
         }
 
         $start = time();
         // write to db
-        $ins = mysql_query("INSERT INTO tasks (start,end,title,text,liste,status,project) VALUES ('$start','$end_fin','$title','$text',$liste,1,$project)");
-        if ($ins)
-        {
-            $insid = mysql_insert_id();
+        $insStmt = $conn->prepare("INSERT INTO tasks (start,end,title,text,liste,status,project) VALUES (?, ?, ?, ?, ?, 1, ?)");
+        $ins = $insStmt->execute(array($start, $end_fin, $title, $text, $liste, $project));
+        if ($ins) {
+            $insid = $conn->lastInsertId();
             // logentry
             $nameproject = $this->getNameProject($insid);
             $this->mylog->add($nameproject[0], 'task', 1, $nameproject[1]);
             return $insid;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -81,26 +74,21 @@ class task
      */
     function edit($id, $end, $title, $text, $liste)
     {
-        $end = mysql_real_escape_string($end);
-        $title = mysql_real_escape_string($title);
-        $text = mysql_real_escape_string($text);
+        global $conn;
         $id = (int) $id;
         $liste = (int) $liste;
 
         $end = strtotime($end);
 
-        $upd = mysql_query("UPDATE tasks SET `end`='$end',`title`='$title', `text`='$text', `liste`=$liste WHERE ID = $id");
-		mysql_query("DELETE FROM tasks_assigned WHERE `task` = $id");
+        $updStmt = $conn->prepare("UPDATE tasks SET `end`=?,`title`=?, `text`=?, `liste`=? WHERE ID = ?");
+        $conn->query("DELETE FROM tasks_assigned WHERE `task` = $id");
+        $upd = $updStmt->execute(array($end, $title, $text, $liste, $id));
 
-
-        if ($upd)
-        {
+        if ($upd) {
             $nameproject = $this->getNameProject($id);
             $this->mylog->add($nameproject[0], 'task', 2, $nameproject[1]);
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -113,18 +101,16 @@ class task
      */
     function del($id)
     {
+        global $conn;
         $id = (int) $id;
 
         $nameproject = $this->getNameProject($id);
-        $del = mysql_query("DELETE FROM tasks WHERE ID = $id LIMIT 1");
-        if ($del)
-        {
-            $del2 = mysql_query("DELETE FROM tasks_assigned WHERE task=$id");
+        $del = $conn->query("DELETE FROM tasks WHERE ID = $id LIMIT 1");
+        if ($del) {
+            $del2 = $conn->query("DELETE FROM tasks_assigned WHERE task=$id");
             $this->mylog->add($nameproject[0], 'task', 3, $nameproject[1]);
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -137,17 +123,15 @@ class task
      */
     function open($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $upd = mysql_query("UPDATE tasks SET status = 1 WHERE ID = $id");
-        if ($upd)
-        {
+        $upd = $conn->query("UPDATE tasks SET status = 1 WHERE ID = $id");
+        if ($upd) {
             $nameproject = $this->getNameProject($id);
             $this->mylog->add($nameproject[0], 'task', 4, $nameproject[1]);
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -160,31 +144,29 @@ class task
      */
     function close($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $upd = mysql_query("UPDATE tasks SET status = 0 WHERE ID = $id");
+        $upd = $conn->query("UPDATE tasks SET status = 0 WHERE ID = $id");
 
         /*
-        $sql = mysql_query("SELECT liste FROM tasks WHERE ID = $id");
-        $liste = mysql_fetch_row($sql);
-        $sql2 = mysql_query("SELECT count(*) FROM tasks WHERE liste = $liste[0] AND status = 1");
-        $cou = mysql_fetch_row($sql2);
+        $sql = $conn->query("SELECT liste FROM tasks WHERE ID = $id");
+        $liste = $sql->fetch();
+        $sql2 = $conn->query("SELECT count(*) FROM tasks WHERE liste = $liste[0] AND status = 1");
+        $cou = $sql2->fetch();
         // if this is the last task in its list, close the list too.
         if ($cou[0] == 0)
         {
             $tasklist = new tasklist();
             $tasklist->close_liste($liste[0]);
         }
-		*/
+                */
 
-        if ($upd)
-        {
+        if ($upd) {
             $nameproject = $this->getNameProject($id);
             $this->mylog->add($nameproject[0], 'task', 5, $nameproject[1]);
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -198,16 +180,14 @@ class task
      */
     function assign($task, $id)
     {
+        global $conn;
         $task = (int) $task;
         $id = (int) $id;
 
-        $upd = mysql_query("INSERT INTO tasks_assigned (user,task) VALUES ($id,$task)");
-        if ($upd)
-        {
+        $upd = $conn->query("INSERT INTO tasks_assigned (user,task) VALUES ($id,$task)");
+        if ($upd) {
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -221,16 +201,14 @@ class task
      */
     function deassign($task, $id)
     {
+        global $conn;
         $task = (int) $task;
         $id = (int) $id;
 
-        $upd = mysql_query("DELETE FROM tasks_assigned WHERE user = $id AND task = $task");
-        if ($upd)
-        {
+        $upd = $conn->query("DELETE FROM tasks_assigned WHERE user = $id AND task = $task");
+        if ($upd) {
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -243,18 +221,16 @@ class task
      */
     function getTask($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $sel = mysql_query("SELECT * FROM tasks WHERE ID = $id");
-        $task = mysql_fetch_array($sel, MYSQL_ASSOC);
-        if (!empty($task))
-        {
+        $task = $conn->query("SELECT * FROM tasks WHERE ID = $id")->fetch();
+        if (!empty($task)) {
             // format datestring according to dateformat option
-
             if (is_numeric($task['end'])) {
-            	$endstring = date(CL_DATEFORMAT, $task["end"]);
+                $endstring = date(CL_DATEFORMAT, $task["end"]);
             } else {
-            	$endstring = date(CL_DATEFORMAT, strtotime($task["end"]));
+                $endstring = date(CL_DATEFORMAT, strtotime($task["end"]));
             }
             // get list and projectname of the task
             $details = $this->getTaskDetails($task);
@@ -263,37 +239,30 @@ class task
             // get remainig days until due date
             $tage = $this->getDaysLeft($task['end']);
 
-            $usel = mysql_query("SELECT user FROM tasks_assigned WHERE task = $task[ID]");
+            $usel = $conn->query("SELECT user FROM tasks_assigned WHERE task = $task[ID]");
             $users = array();
-            while ($usr = mysql_fetch_row($usel))
-            {
+            while ($usr = $usel->fetch()) {
                 array_push($users, $usr[0]);
                 $task["user"] = "All";
                 $task["user_id"] = $users;
             }
-            if (count($users) == 1)
-            {
-            	$usrobj = new user();
+            if (count($users) == 1) {
+                $usrobj = new user();
                 $usr = $users[0];
                 $user = $usrobj->getProfile($usr);
                 $task["user"] = stripslashes($user["name"]);
                 $task["users"] = array($user);
                 $task["user_id"] = $user["ID"];
-
-            }
-            elseif(count($users) > 1)
-            {
-
+            } elseif (count($users) > 1) {
                 $usrobj = new user();
                 $task["users"] = array();
                 $task["user"] = "";
                 $task["user_id"] = 0;
-                foreach($users as $user)
-                {
+                foreach($users as $user) {
                     $usr = $usrobj->getProfile($user);
-                    $task["user"] .=  $usr["name"] . " ";
-                	array_push($task["users"],$usr);
-				}
+                    $task["user"] .= $usr["name"] . " ";
+                    array_push($task["users"], $usr);
+                }
             }
 
             $task["endstring"] = $endstring;
@@ -305,9 +274,7 @@ class task
             $task["daysleft"] = $tage;
 
             return $task;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -320,30 +287,23 @@ class task
      */
     function getProjectTasks($project, $status = 1)
     {
+        global $conn;
         $project = (int) $project;
         $status = (int) $status;
 
         $lists = array();
-        if ($status !== false)
-        {
-            $sel2 = mysql_query("SELECT ID FROM tasks WHERE project = $project AND status=$status");
-        }
-        else
-        {
-            $sel2 = mysql_query("SELECT ID FROM tasks WHERE project = $project");
-        }
-        while ($tasks = mysql_fetch_array($sel2, MYSQL_ASSOC))
-        {
+        if ($status !== false) {
+            $sel2 = $conn->query("SELECT ID FROM tasks WHERE project = $project AND status=$status");
+        } else {
+            $sel2 = $conn->query("SELECT ID FROM tasks WHERE project = $project");
+        } while ($tasks = $sel2->fetch()) {
             $task = $this->getTask($tasks["ID"]);
             array_push($lists, $task);
         }
 
-        if (!empty($lists))
-        {
+        if (!empty($lists)) {
             return $lists;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -357,6 +317,7 @@ class task
      */
     function getMyProjectTasks($project, $limit = 10)
     {
+        global $conn;
         $project = (int) $project;
         $limit = (int) $limit;
 
@@ -364,25 +325,20 @@ class task
         $lists = array();
         $now = time();
 
-        $sel2 = mysql_query("SELECT ID FROM tasks WHERE project = $project AND status=1 AND end > $now ORDER BY `end` ASC LIMIT $limit");
+        $sel2 = $conn->query("SELECT ID FROM tasks WHERE project = $project AND status=1 AND end > $now ORDER BY `end` ASC LIMIT $limit");
 
-        while ($tasks = mysql_fetch_array($sel2, MYSQL_ASSOC))
-        {
-            $chk = mysql_fetch_row(mysql_query("SELECT ID FROM tasks_assigned WHERE user = $user AND task = $tasks[ID]"));
+        while ($tasks = $sel2->fetch()) {
+            $chk = $conn->query("SELECT ID FROM tasks_assigned WHERE user = $user AND task = $tasks[ID]")->fetch();
             $chk = $chk[0];
-            if ($chk)
-            {
+            if ($chk) {
                 $task = $this->getTask($tasks["ID"]);
                 array_push($lists, $task);
             }
         }
 
-        if (!empty($lists))
-        {
+        if (!empty($lists)) {
             return $lists;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -397,31 +353,27 @@ class task
      */
     function getAllMyProjectTasks($project, $limit = 10, $user = 0)
     {
+        global $conn;
         $project = (int) $project;
         $limit = (int) $limit;
         $user = (int) $user;
 
-        if ($user < 1)
-        {
+        if ($user < 1) {
             $user = $_SESSION['userid'];
         }
         $lists = array();
         $now = time();
 
-        $sel2 = mysql_query("SELECT tasks.*,tasks_assigned.user FROM tasks,tasks_assigned WHERE tasks.ID = tasks_assigned.task HAVING tasks_assigned.user = $user AND tasks.project = $project AND status=1 ORDER BY `end` ASC ");
+        $sel2 = $conn->query("SELECT tasks.*,tasks_assigned.user FROM tasks,tasks_assigned WHERE tasks.ID = tasks_assigned.task HAVING tasks_assigned.user = $user AND tasks.project = $project AND status=1 ORDER BY `end` ASC ");
 
-        while ($tasks = mysql_fetch_array($sel2, MYSQL_ASSOC))
-        {
+        while ($tasks = $sel2->fetch()) {
             $task = $this->getTask($tasks["ID"]);
             array_push($lists, $task);
         }
 
-        if (!empty($lists))
-        {
+        if (!empty($lists)) {
             return $lists;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -435,6 +387,7 @@ class task
      */
     function getMyLateProjectTasks($project, $limit = 10)
     {
+        global $conn;
         $project = (int) $project;
         $limit = (int) $limit;
 
@@ -443,19 +396,15 @@ class task
         $tod = date("d.m.Y");
         $now = strtotime($tod);
 
-        $sel2 = mysql_query("SELECT tasks.*,tasks_assigned.user FROM tasks,tasks_assigned WHERE tasks.ID = tasks_assigned.task HAVING tasks_assigned.user = $user AND tasks.project = $project  AND status=1 AND end < $now ORDER BY `end` ASC LIMIT $limit");
-        while ($tasks = mysql_fetch_array($sel2, MYSQL_ASSOC))
-        {
+        $sel2 = $conn->query("SELECT tasks.*,tasks_assigned.user FROM tasks,tasks_assigned WHERE tasks.ID = tasks_assigned.task HAVING tasks_assigned.user = $user AND tasks.project = $project  AND status=1 AND end < $now ORDER BY `end` ASC LIMIT $limit");
+        while ($tasks = $sel2->fetch()) {
             $task = $this->getTask($tasks["ID"]);
             array_push($lists, $task);
         }
 
-        if (!empty($lists))
-        {
+        if (!empty($lists)) {
             return $lists;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -469,6 +418,7 @@ class task
      */
     function getMyTodayProjectTasks($project, $limit = 10)
     {
+        global $conn;
         $project = (int) $project;
         $limit = (int) $limit;
 
@@ -477,20 +427,16 @@ class task
         $lists = array();
         $now = strtotime($tod);
 
-        $sel2 = mysql_query("SELECT tasks.*,tasks_assigned.user FROM tasks,tasks_assigned WHERE tasks.ID = tasks_assigned.task HAVING tasks_assigned.user = $user AND tasks.project = $project  AND status=1 AND end = '$now' ORDER BY `end` ASC LIMIT $limit");
+        $sel2 = $conn->query("SELECT tasks.*,tasks_assigned.user FROM tasks,tasks_assigned WHERE tasks.ID = tasks_assigned.task HAVING tasks_assigned.user = $user AND tasks.project = $project  AND status=1 AND end = '$now' ORDER BY `end` ASC LIMIT $limit");
 
-        while ($tasks = mysql_fetch_array($sel2, MYSQL_ASSOC))
-        {
+        while ($tasks = $sel2->fetch()) {
             $task = $this->getTask($tasks["ID"]);
             array_push($lists, $task);
         }
 
-        if (!empty($lists))
-        {
+        if (!empty($lists)) {
             return $lists;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -504,6 +450,7 @@ class task
      */
     function getMyDoneProjectTasks($project, $limit = 5)
     {
+        global $conn;
         $project = (int) $project;
         $limit = (int) $limit;
 
@@ -511,44 +458,38 @@ class task
         $lists = array();
         $now = time();
 
-        $sel2 = mysql_query("SELECT tasks.*,tasks_assigned.user FROM tasks,tasks_assigned WHERE tasks.ID = tasks_assigned.task HAVING tasks_assigned.user = $user AND tasks.project = $project AND status=0 ORDER BY `end` ASC LIMIT $limit");
+        $sel2 = $conn->query("SELECT tasks.*,tasks_assigned.user FROM tasks,tasks_assigned WHERE tasks.ID = tasks_assigned.task HAVING tasks_assigned.user = $user AND tasks.project = $project AND status=0 ORDER BY `end` ASC LIMIT $limit");
 
-        while ($tasks = mysql_fetch_array($sel2, MYSQL_ASSOC))
-        {
+        while ($tasks = $sel2->fetch()) {
             $task = $this->getTask($tasks["ID"]);
             array_push($lists, $task);
         }
 
-        if (!empty($lists))
-        {
+        if (!empty($lists)) {
             return $lists;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
 
-	/**
+    /**
      * Return all tasks (from a project) due on the specified date
      *
-	 * @param int $m Month
-	 * @param int $y Year
-	 * @param int $d Day
+     * @param int $m Month
+     * @param int $y Year
+     * @param int $d Day
      * @param int $project Project ID (Default: 0 = all projects)
      * @return array $timeline Tasks
      */
     function getTodayTasks($m, $y, $d, $project = 0)
     {
+        global $conn;
         $m = (int) $m;
         $y = (int) $y;
 
-        if ($m > 9)
-        {
+        if ($m > 9) {
             $startdate = date($d . "." . $m . "." . $y);
-        }
-        else
-        {
+        } else {
             $startdate = date($d . ".0" . $m . "." . $y);
         }
         $starttime = strtotime($startdate);
@@ -556,28 +497,21 @@ class task
         $user = (int) $_SESSION["userid"];
         $timeline = array();
 
-        if ($project > 0)
-        {
+        if ($project > 0) {
             $sql = "SELECT * FROM tasks  WHERE status=1 AND project = $project AND end = '$starttime'";
+        } else {
+            $sql = "SELECT tasks.*,tasks_assigned.user,projekte.name AS pname FROM tasks,tasks_assigned,projekte WHERE tasks.ID = tasks_assigned.task AND tasks.project = projekte.ID HAVING tasks_assigned.user = $user AND status=1 AND end = '$starttime'";
         }
-        else
-        {
-			$sql = "SELECT tasks.*,tasks_assigned.user,projekte.name AS pname FROM tasks,tasks_assigned,projekte WHERE tasks.ID = tasks_assigned.task AND tasks.project = projekte.ID HAVING tasks_assigned.user = $user AND status=1 AND end = '$starttime'";
-        }
-        $sel1 = mysql_query($sql);
+        $sel1 = $conn->query($sql);
 
-        while ($stone = mysql_fetch_array($sel1, MYSQL_ASSOC))
-        {
+        while ($stone = $sel1->fetch()) {
             $stone["daysleft"] = $this->getDaysLeft($stone["end"]);
             array_push($timeline, $stone);
         }
 
-        if (!empty($timeline))
-        {
+        if (!empty($timeline)) {
             return $timeline;
-        }
-        else
-        {
+        } else {
             return array();
         }
     }
@@ -590,22 +524,18 @@ class task
      */
     function getUser($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $sql = mysql_query("SELECT user FROM tasks_assigned WHERE task = $id");
-        $user = mysql_fetch_row($sql);
+        $user = $conn->query("SELECT user FROM tasks_assigned WHERE task = $id")->fetch();
 
-        if (!empty($user))
-        {
-            $sel2 = mysql_query("SELECT name FROM user WHERE ID = $user[0]");
-            $uname = mysql_fetch_row($sel2);
+        if (!empty($user)) {
+            $uname = $conn->query("SELECT name FROM user WHERE ID = $user[0]")->fetch();
             $uname = $uname[0];
             $user[1] = stripslashes($uname);
 
             return $user;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -618,28 +548,23 @@ class task
      */
     function getUsers($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $sql = mysql_query("SELECT user FROM tasks_assigned WHERE task = $id");
-        if (mysql_num_rows($sql) > 0)
-        {
+        $sql = $conn->query("SELECT user FROM tasks_assigned WHERE task = $id");
+
             $result = array();
-            while ($user = mysql_fetch_row($sql)) {
+            while ($user = $sql->fetch()) {
 
-
-                $sel2 = mysql_query("SELECT name FROM user WHERE ID = $user[0]");
-                $uname = mysql_fetch_row($sel2);
+                $sel2 = $conn->query("SELECT name FROM user WHERE ID = $user[0]");
+                $uname = $sel2->fetch();
                 $uname = $uname[0];
                 $user[1] = stripslashes($uname);
 
                 $result[] = $user;
             }
             return $result;
-        }
-        else
-        {
-            return false;
-        }
+
     }
 
     /**
@@ -656,14 +581,11 @@ class task
         $project = new project();
         $myprojects = $project->getMyProjects($user);
         $tasks = array();
-        if (!empty($myprojects))
-        {
-            foreach($myprojects as $proj)
-            {
+        if (!empty($myprojects)) {
+            foreach($myprojects as $proj) {
                 $task = $this->getAllMyProjectTasks($proj["ID"], 10000);
 
-                if (!empty($task))
-                {
+                if (!empty($task)) {
                     array_push($tasks, $task);
                 }
             }
@@ -682,8 +604,7 @@ class task
         $cal->setProperty('X-WR-CALDESC' , '');
         $cal->setProperty('CALSCALE' , 'GREGORIAN');
         $cal->setProperty('METHOD' , 'PUBLISH');
-        foreach($etasks as $etask)
-        {
+        foreach($etasks as $etask) {
             // split date in Y / M / D / h / min / sek variables
             $jahr = date("Y", $etask["start"]);
             $monat = date("m", $etask["start"]);
@@ -725,25 +646,21 @@ class task
      */
     private function getTaskDetails(array $task)
     {
-        $psel = mysql_query("SELECT name FROM projekte WHERE ID = $task[project]");
-        $pname = mysql_fetch_row($psel);
+        global $conn;
+        $psel = $conn->query("SELECT name FROM projekte WHERE ID = $task[project]");
+        $pname = $psel->fetch();
         $pname = stripslashes($pname[0]);
 
-        $list = mysql_query("SELECT name FROM tasklist WHERE ID = $task[liste]");
-        $list = mysql_fetch_row($list);
+        $list = $conn->query("SELECT name FROM tasklist WHERE ID = $task[liste]")->fetch();
         $list = stripslashes($list[0]);
 
-        if (isset($list) or isset($pname))
-        {
+        if (isset($list) or isset($pname)) {
             $details = array("list" => $list, "pname" => $pname);
         }
 
-        if (!empty($details))
-        {
+        if (!empty($details)) {
             return $details;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -771,23 +688,19 @@ class task
      */
     private function getNameProject($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $nam = mysql_query("SELECT text,liste,title FROM tasks WHERE ID = $id");
-        $nam = mysql_fetch_row($nam);
+        $nam = $conn->query("SELECT text,liste,title FROM tasks WHERE ID = $id")->fetch();
         $text = stripslashes($nam[2]);
         $list = $nam[1];
-        $sel2 = mysql_query("SELECT project FROM tasklist WHERE ID = $list");
-        $project = mysql_fetch_row($sel2);
+        $project = $conn->query("SELECT project FROM tasklist WHERE ID = $list")->fetch();
         $project = $project[0];
         $nameproject = array($text, $project);
 
-        if (!empty($nameproject))
-        {
+        if (!empty($nameproject)) {
             return $nameproject;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
