@@ -2,16 +2,15 @@
 /**
  * This class provides methods to realize timetracking
  *
- * @author Open Dynamics <info@o-dyn.de>
+ * @author Philipp Kiszka <info@o-dyn.de>
  * @name timetracker
- * @version 0.4.7
+ * @version 1.0
  * @package Collabtive
  * @link http://www.o-dyn.de
  * @license http://opensource.org/licenses/gpl-license.php GNU General Public License v3 or later
  */
 
-class timetracker
-{
+class timetracker {
     private $mylog;
 
     /**
@@ -36,22 +35,14 @@ class timetracker
      */
     function add($user, $project, $task, $comment, $started, $ended, $logday = "")
     {
-        $started = mysql_real_escape_string($started);
-        $ended = mysql_real_escape_string($ended);
-        $comment = mysql_real_escape_string($comment);
+        global $conn;
         $username = $_SESSION['username'];
-        $user = (int) $user;
-        $project = (int) $project;
-        $task = (int) $task;
 
-		if(!$logday)
-		{
-        	$startdate = date("d.m.Y");
-		}
-		else
-		{
-			$startdate = $logday;
-		}
+        if (!$logday) {
+            $startdate = date(CL_DATEFORMAT);
+        } else {
+            $startdate = $logday;
+        }
 
         $started = $startdate . " " . $started;
         $started = strtotime($started);
@@ -61,21 +52,20 @@ class timetracker
         $hours = $ended - $started;
         $hours = $hours / 3600;
         $hours = round($hours, 2);
-        if ($started >= $ended)
-        {
+
+        if ($started >= $ended) {
             return false;
         }
-        $ins = mysql_query("INSERT INTO timetracker (user,project,task,comment,started,ended,hours,pstatus) VALUES ($user,$project,$task,'$comment','$started','$ended','$hours',0)");
 
-        if ($ins)
-        {
-            $insid = mysql_insert_id();
+        $insStmt = $conn->prepare("INSERT INTO timetracker (user,project,task,comment,started,ended,hours,pstatus) VALUES (?,?,?,?,?,?,?,0)");
+        $ins = $insStmt->execute(array((int) $user, (int) $project, (int) $task, $comment, $started, $ended, $hours));
+
+        if ($ins) {
+            $insid = $conn->lastInsertId();
             $title = $username . " " . $hours . "h";
-            //$this->mylog->add($title, "track", 1, $project);
+
             return $insid;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -92,14 +82,9 @@ class timetracker
      */
     function edit($id, $task, $comment, $started, $ended)
     {
-        $comment = mysql_real_escape_string($comment);
-        $started = (int) $started;
-        $ended = (int) $ended;
-        $id = (int) $id;
-        $task = (int) $task;
+        global $conn;
 
-        if ($started >= $ended)
-        {
+        if ($started >= $ended) {
             return false;
         }
 
@@ -107,13 +92,12 @@ class timetracker
         $hours = $hours / 3600;
         $hours = round($hours, 2);
 
-        $upd = mysql_query("UPDATE timetracker SET task='$task',comment='$comment',started='$started',ended='$ended',hours='$hours' WHERE ID = $id");
-        if ($upd)
-        {
+        $updStmt = $conn->prepare("UPDATE timetracker SET task=?, comment=?, started=?, ended=?, hours=? WHERE ID = ?");
+        $upd = $updStmt->execute(array((int) $task, $comment, (int) $started, (int) $ended, $hours, (int) $id));
+
+        if ($upd) {
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -125,30 +109,28 @@ class timetracker
      */
     function del($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $del = mysql_query("DELETE FROM timetracker WHERE ID = $id");
-        if ($del)
-        {
+        $del = $conn->query("DELETE FROM timetracker WHERE ID = $id");
+
+        if ($del) {
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
 
     function setPaystatus($pstatus, $id)
     {
+        global $conn;
         $pstatus = (int) $pstatus;
         $id = (int) $id;
-        $upd = mysql_query("UPDATE timetracker SET pstatus = $pstatus WHERE ID = $id");
-        if ($upd)
-        {
+        $upd = $conn->query("UPDATE timetracker SET pstatus = $pstatus WHERE ID = $id");
+
+        if ($upd) {
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -160,79 +142,71 @@ class timetracker
      */
     function getTrack($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $sel = mysql_query("SELECT * FROM timetracker WHERE ID = $id");
+        $sel = $conn->query("SELECT * FROM timetracker WHERE ID = $id");
         $track = array();
-        $track = mysql_fetch_array($sel);
+        $track = $sel->fetch();
 
-        if (!empty($track))
-        {
-            if (isset($track["started"]) and isset($track["ended"]))
-            {
+        if (!empty($track)) {
+            if (isset($track["started"]) and isset($track["ended"])) {
                 $hours = $track["ended"] - $track["started"];
                 $hours = $hours / 3600;
                 $hours = round($hours, 2);
                 $track["hours"] = $hours;
 
-                $day = date("d.m.Y", $track["started"]);
+                $day = date(CL_DATEFORMAT, $track["started"]);
                 $track["started"] = date("H:i", $track["started"]);
                 $track["ended"] = date("H:i", $track["ended"]);
 
                 $track["day"] = $day;
             }
-            if (isset($track["comment"]))
-            {
+
+            if (isset($track["comment"])) {
                 $track["comment"] = stripslashes($track["comment"]);
             }
+
             return $track;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
 
     function getUserTrack($user, $project = 0, $task = 0, $start = 0, $end = 0 , $lim = 50)
     {
-        $start = mysql_real_escape_string($start);
-        $end = mysql_real_escape_string($end);
+        global $conn;
         $user = (int) $user;
         $project = (int) $project;
         $lim = (int) $lim;
 
-        if ($project > 0)
-        {
+        if ($project > 0) {
             $sql = "SELECT * FROM timetracker WHERE user = $user AND project = $project";
             $num = "SELECT COUNT(*) FROM timetracker WHERE project = $project AND user = $user";
             $order = " ORDER BY ended ASC";
-        }
-        else
-        {
+        } else {
             $sql = "SELECT * FROM timetracker WHERE user = $user";
             $num = "SELECT COUNT(*) FROM timetracker WHERE user = $user";
             $order = " ORDER BY ended ASC";
         }
-        if ($task > 0)
-        {
+
+        if ($task > 0) {
             $sql .= " AND task = $task";
             $num .= " AND task = $task";
         }
-        if ($start > 0 and $end > 0)
-        {
+
+        if ($start > 0 and $end > 0) {
             $start = strtotime($start);
             $end = strtotime($end . " +1 day");
             $end = $end - 1;
-			$sql .= " AND ended >=$start AND ended<=$end ";
+            $sql .= " AND ended >=$start AND ended<=$end ";
             $num .= " AND ended >=$start AND ended<=$end ";
         }
-        if ($num)
-        {
-            $num = mysql_fetch_row(mysql_query($num));
+
+        if ($num) {
+            $num = $conn->query($num)->fetch();
             $num = $num[0];
-        }
-        else
-        {
+        } else {
             $num = 0;
         }
 
@@ -247,29 +221,26 @@ class timetracker
         $limi = " LIMIT $start,$lim";
         $sql = $sql . $limi;
 
-        $sel = mysql_query($sql);
+        $sel = $conn->query($sql);
         $track = array();
         $ttask = new task();
-        if (isset($sel))
-        {
-            while ($data = @mysql_fetch_array($sel))
-            {
+
+        if (isset($sel)) {
+            while ($data = @$sel->fetch()) {
                 $endstring = date("H:i", $data["ended"]);
                 $startstring = date("H:i", $data["started"]);
                 $daystring = date("d.m.y", $data["ended"]);
                 $tasks = $ttask->getTask($data["task"]);
-                if (!empty($tasks))
-                {
+
+                if (!empty($tasks)) {
                     $tasks = $tasks["title"];
                     $data["tname"] = $tasks;
                 }
 
-                $pname = mysql_query("SELECT name FROM projekte WHERE ID = $data[project]");
-                $pname = mysql_fetch_row($pname);
+                $pname = $conn->query("SELECT name FROM projekte WHERE ID = $data[project]")->fetch();
                 $pname = stripslashes($pname[0]);
 
-                $uname = mysql_query("SELECT name FROM user WHERE ID = $data[user]");
-                $uname = mysql_fetch_row($uname);
+                $uname = $conn->query("SELECT name FROM user WHERE ID = $data[user]")->fetch();
                 $uname = stripslashes($uname[0]);
 
                 $data["endstring"] = $endstring;
@@ -283,60 +254,51 @@ class timetracker
             }
         }
 
-        if (!empty($track))
-        {
+        if (!empty($track)) {
             return $track;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
 
     function getProjectTrack($project, $user = 0, $task = 0, $start = 0, $end = 0, $lim = 50)
     {
-        $start = mysql_real_escape_string($start);
-        $end = mysql_real_escape_string($end);
+        global $conn;
         $project = (int) $project;
         $user = (int) $user;
         $lim = (int) $lim;
 
-        if ($user > 0)
-        {
+        if ($user > 0) {
             $sql = "SELECT * FROM timetracker WHERE project = $project AND user = $user";
             $num = "SELECT COUNT(*) FROM timetracker WHERE project = $project AND user = $user";
             $order = " ORDER BY ended ASC";
-        }
-        else
-        {
+        } else {
             $sql = "SELECT * FROM timetracker WHERE project = $project";
             $num = "SELECT COUNT(*) FROM timetracker WHERE project = $project";
             $order = " ORDER BY ended ASC";
         }
-        if ($task > 0)
-        {
+
+        if ($task > 0) {
             $sql .= " AND task = $task";
             $num .= " AND task = $task";
         }
-        if ($start > 0 and $end > 0)
-        {
+
+        if ($start > 0 and $end > 0) {
             $start = strtotime($start);
             $end = strtotime($end . " +1 day");
             $end = $end - 1;
             $sql .= " AND ended >=$start AND ended<=$end ";
             $num .= " AND ended >=$start AND ended<=$end ";
         }
-        if ($num)
-        {
-            $num = mysql_fetch_row(mysql_query($num));
+
+        if ($num) {
+            $num = $conn->query($num)->fetch();
             $num = $num[0];
-        }
-        else
-        {
+        } else {
             $num = 0;
         }
 
-
+        $sql = $sql . $order;
         SmartyPaginate::connect();
         SmartyPaginate::setLimit($lim);
         SmartyPaginate::setTotal($num);
@@ -347,30 +309,27 @@ class timetracker
         $limi = " LIMIT $start,$lim ";
         $sql = $sql . $limi;
 
-        $sel = mysql_query($sql);
+        $sel = $conn->query($sql);
 
         $track = array();
         $ttask = new task();
-        if (isset($sel))
-        {
-            while ($data = @mysql_fetch_array($sel))
-            {
+
+        if (isset($sel)) {
+            while ($data = @$sel->fetch()) {
                 $endstring = date("H:i", $data["ended"]);
                 $startstring = date("H:i", $data["started"]);
-                $daystring = date("d.m.y", $data["ended"]);
+                $daystring = date(CL_DATEFORMAT, $data["ended"]);
                 $tasks = $ttask->getTask($data["task"]);
-                if (!empty($tasks))
-                {
+
+                if (!empty($tasks)) {
                     $tasks = $tasks["title"];
                     $data["tname"] = $tasks;
                 }
 
-                $pname = mysql_query("SELECT name FROM projekte WHERE ID = $data[project]");
-                $pname = mysql_fetch_row($pname);
+                $pname = $conn->query("SELECT name FROM projekte WHERE ID = $data[project]")->fetch();
                 $pname = stripslashes($pname[0]);
 
-                $uname = mysql_query("SELECT name FROM user WHERE ID = $data[user]");
-                $uname = mysql_fetch_row($uname);
+                $uname = $conn->query("SELECT name FROM user WHERE ID = $data[user]")->fetch();
                 $uname = stripslashes($uname[0]);
 
                 $data["endstring"] = $endstring;
@@ -383,12 +342,10 @@ class timetracker
                 array_push($track, $data);
             }
         }
-        if (!empty($track))
-        {
+
+        if (!empty($track)) {
             return $track;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -402,15 +359,15 @@ class timetracker
     function getTotalTrackTime(array $track)
     {
         $totaltime = 0;
-        foreach($track as $data)
-        {
+
+        foreach($track as $data) {
             $totaltime = $totaltime + $data["hours"];
         }
 
-        if (!($totaltime > 0))
-        {
+        if (!($totaltime > 0)) {
             $totaltime = 0;
         }
+
         return $totaltime;
     }
 }
