@@ -9,8 +9,7 @@
  * @link http://www.o-dyn.de
  * @license http://opensource.org/licenses/gpl-license.php GNU General Public License v3 or laterg
  */
-class user
-{
+class user {
     public $mylog;
 
     /**
@@ -30,31 +29,22 @@ class user
      * @param string $company Company of the member
      * @param string $pass Password
      * @param string $locale Localisation
-	 * @param float $rate Hourly rate
+     * @param float $rate Hourly rate
      * @return int $insid ID of the newly created member
      */
     function add($name, $email, $company, $pass, $locale = "", $tags = "", $rate = 0.0)
     {
-        $name = mysql_real_escape_string($name);
-        $email = mysql_real_escape_string($email);
-		$company = mysql_real_escape_string($company);
-		$pass = mysql_real_escape_string($pass);
-        $locale = mysql_real_escape_string($locale);
-        $tags = mysql_real_escape_string($tags);
-        $rate = (float) $rate;
-
+        global $conn;
         $pass = sha1($pass);
 
-        $ins1 = mysql_query("INSERT INTO user (name,email,company,pass,locale,tags,rate) VALUES ('$name','$email','$company','$pass','$locale','$tags','$rate')");
+        $ins1Stmt = $conn->prepare("INSERT INTO user (name,email,company,pass,locale,tags,rate) VALUES (?, ?, ?, ?, ?, ?, ?)");
+        $ins1 = $ins1Stmt->execute(array($name, $email, $company, $pass, $locale, $tags, $rate));
 
-        if ($ins1)
-        {
-            $insid = mysql_insert_id();
+        if ($ins1) {
+            $insid = $conn->lastInsertId();
             $this->mylog->add($name, 'user', 1, 0);
             return $insid;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -81,41 +71,23 @@ class user
      */
     function edit($id, $name, $realname, $email, $tel1, $tel2, $company, $zip, $gender, $url, $address1, $address2, $state, $country, $tags, $locale, $avatar = "", $rate = 0.0)
     {
-        $name = mysql_real_escape_string($name);
-        $realname = mysql_real_escape_string($realname);
-		$company = mysql_real_escape_string($company);
-        $email = mysql_real_escape_string($email);
-        $tel1 = mysql_real_escape_string($tel1);
-        $tel2 = mysql_real_escape_string($tel2);
-        $zip = mysql_real_escape_string($zip);
-        $gender = mysql_real_escape_string($gender);
-        $url = mysql_real_escape_string($url);
-        $address1 = mysql_real_escape_string($address1);
-        $address2 = mysql_real_escape_string($address2);
-        $state = mysql_real_escape_string($state);
-        $country = mysql_real_escape_string($country);
-        $tags = mysql_real_escape_string($tags);
-        $locale = mysql_real_escape_string($locale);
-        $avatar = mysql_real_escape_string($avatar);
+        global $conn;
 
         $rate = (float) $rate;
         $id = (int) $id;
 
-        if ($avatar != "")
-        {
-            $upd = mysql_query("UPDATE user SET name='$name',email='$email',tel1='$tel1', tel2='$tel2',company='$company',zip='$zip',gender='$gender',url='$url',adress='$address1',adress2='$address2',state='$state',country='$country',tags='$tags',locale='$locale',avatar='$avatar',rate='$rate' WHERE ID = $id");
+        if ($avatar != "") {
+            $updStmt = $conn->prepare("UPDATE user SET name=?, email=?, tel1=?, tel2=?, company=?, zip=?, gender=?, url=?, adress=?, adress2=?, state=?, country=?, tags=?, locale=?, avatar=?, rate=? WHERE ID = ?");
+            $upd = $updStmt->execute(array($name, $email, $tel1, $tel2, $company, $zip, $gender, $url, $address1, $address2, $state, $country, $tags, $locale, $avatar, $rate, $id));
+        } else {
+            $updStmt = $conn->prepare("UPDATE user SET name=?, email=?, tel1=?, tel2=?, company=?, zip=?, gender=?, url=?, adress=?, adress2=?, state=?, country=?, tags=?, locale=?, rate=? WHERE ID = ?");
+            $upd = $updStmt->execute(array($name, $email, $tel1, $tel2, $company, $zip, $gender, $url, $address1, $address2, $state, $country, $tags, $locale, $rate, $id));
         }
-        else
-        {
-            $upd = mysql_query("UPDATE user SET name='$name',email='$email', tel1='$tel1', tel2='$tel2', company='$company',zip='$zip',gender='$gender',url='$url',adress='$address1',adress2='$address2',state='$state',country='$country',tags='$tags',locale='$locale',rate='$rate' WHERE ID = $id");
-        }
-        if ($upd)
-        {
+
+        if ($upd) {
             $this->mylog->add($name, 'user', 2, 0);
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -128,44 +100,34 @@ class user
      */
     function resetPassword($email)
     {
-		$email = mysql_real_escape_string($email);
-		
-		$sel = mysql_query("SELECT ID, email FROM user");
-		while ($user = mysql_fetch_array($sel))
-		{
-			if ($user["email"] == $email)
-			{
-				$id = $user["ID"];
-			}
-		}
-		
-		if (isset($id))
-		{
- 			$dummy = array_merge(range('0', '9'), range('a', 'z'), range('A', 'Z'),range('0','9'));
- 			shuffle($dummy);
- 			mt_srand((double)microtime()*1000000);
- 			$newpass = "";
- 			for ($i = 1; $i <= 10; $i++)
- 			{
- 				$swap = mt_rand(0,count($dummy)-1);
- 				$tmp = $dummy[$swap];
- 				$newpass .= $tmp;
- 			}
- 			
-			$sha1pass = sha1($newpass);
-			
-			$upd = mysql_query("UPDATE user SET `pass` = '$sha1pass' WHERE ID = $id");
-			if ($upd)
-			{
-				return $newpass;
-			}
-			else
-			{
-				return false;
-			}
-		}
-        else
-        {
+        global $conn;
+
+        $user = $conn->query("SELECT ID, email FROM user WHERE email={$conn->quote($email)} LIMIT 1")->fetch();
+
+        if ($user["email"] == $email) {
+            $id = $user["ID"];
+        }
+
+        if (isset($id)) {
+            $dummy = array_merge(range('0', '9'), range('a', 'z'), range('A', 'Z'), range('0', '9'));
+            shuffle($dummy);
+            mt_srand((double)microtime() * 1000000);
+            $newpass = "";
+            for ($i = 1; $i <= 10; $i++) {
+                $swap = mt_rand(0, count($dummy)-1);
+                $tmp = $dummy[$swap];
+                $newpass .= $tmp;
+            }
+
+            $sha1pass = sha1($newpass);
+
+            $upd = $conn->query("UPDATE user SET `pass` = '$sha1pass' WHERE ID = $id");
+            if ($upd) {
+                return $newpass;
+            } else {
+                return false;
+            }
+        } else {
             return false;
         }
     }
@@ -181,35 +143,26 @@ class user
      */
     function editpass($id, $oldpass, $newpass, $repeatpass)
     {
-        $oldpass = mysql_real_escape_string($oldpass);
-        $newpass = mysql_real_escape_string($newpass);
-        $repeatpass = mysql_real_escape_string($repeatpass);
+        global $conn;
         $id = (int) $id;
 
-        if ($newpass != $repeatpass)
-        {
+        if ($newpass != $repeatpass) {
             return false;
         }
-        $id = mysql_real_escape_string($id);
         $newpass = sha1($newpass);
 
         $oldpass = sha1($oldpass);
-        $chk = mysql_query("SELECT ID, name FROM user WHERE ID = $id AND pass = '$oldpass'");
-        $chk = mysql_fetch_row($chk);
+        $chk = $conn->query("SELECT ID, name FROM user WHERE ID = $id AND pass = {$conn->quote($oldpass)}")->fetch();
         $chk = $chk[0];
         $name = $chk[1];
-        if (!$chk)
-        {
+        if (!$chk) {
             return false;
         }
 
-        $upd = mysql_query("UPDATE user SET pass='$newpass' WHERE ID = $id");
-        if ($upd)
-        {
+        $upd = $conn->query("UPDATE user SET pass={$conn->quote($newpass)} WHERE ID = $id");
+        if ($upd) {
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -224,24 +177,18 @@ class user
      */
     function admin_editpass($id, $newpass, $repeatpass)
     {
-        $newpass = mysql_real_escape_string($newpass);
-        $repeatpass = mysql_real_escape_string($repeatpass);
+        global $conn;
         $id = (int) $id;
 
-        if ($newpass != $repeatpass)
-        {
+        if ($newpass != $repeatpass) {
             return false;
         }
-        $id = mysql_real_escape_string($id);
         $newpass = sha1($newpass);
 
-        $upd = mysql_query("UPDATE user SET pass='$newpass' WHERE ID = $id");
-        if ($upd)
-        {
+        $upd = $conn->query("UPDATE user SET pass={$conn->quote($newpass)} WHERE ID = $id");
+        if ($upd) {
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -254,26 +201,23 @@ class user
      */
     function del($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $chk = mysql_query("SELECT name FROM user WHERE ID = $id");
-        $chk = mysql_fetch_row($chk);
+        $chk = $conn->query("SELECT name FROM user WHERE ID = $id")->fetch();
         $name = $chk[0];
 
-        $del = mysql_query("DELETE FROM user WHERE ID = $id");
-        $del2 = mysql_query("DELETE FROM projekte_assigned WHERE user = $id");
-        $del3 = mysql_query("DELETE FROM milestones_assigned WHERE user = $id");
-        $del4 = mysql_query("DELETE FROM tasks_assigned WHERE user = $id");
-        $del5 = mysql_query("DELETE FROM log WHERE user = $id");
-        $del6 = mysql_query("DELETE FROM timetracker WHERE user = $id");
-		$del7 = mysql_query("DELETE FROM roles_assigned WHERE user = $id");
-        if ($del)
-        {
+        $del = $conn->query("DELETE FROM user WHERE ID = $id");
+        $del2 = $conn->query("DELETE FROM projekte_assigned WHERE user = $id");
+        $del3 = $conn->query("DELETE FROM milestones_assigned WHERE user = $id");
+        $del4 = $conn->query("DELETE FROM tasks_assigned WHERE user = $id");
+        $del5 = $conn->query("DELETE FROM log WHERE user = $id");
+        $del6 = $conn->query("DELETE FROM timetracker WHERE user = $id");
+        $del7 = $conn->query("DELETE FROM roles_assigned WHERE user = $id");
+        if ($del) {
             $this->mylog->add($name, 'user', 3, 0);
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -286,31 +230,26 @@ class user
      */
     function getProfile($id)
     {
+        global $conn;
         $id = (int) $id;
 
-        $sel = mysql_query("SELECT * FROM user WHERE ID = $id");
-        $profile = mysql_fetch_array($sel);
-        if (!empty($profile))
-        {
+        $sel = $conn->query("SELECT * FROM user WHERE ID = $id");
+        $profile = $sel->fetch();
+        if (!empty($profile)) {
             $profile["name"] = stripslashes($profile["name"]);
-            if (isset($profile["company"]))
-            {
+            if (isset($profile["company"])) {
                 $profile["company"] = stripslashes($profile["company"]);
             }
-            if (isset($profile["adress"]))
-            {
+            if (isset($profile["adress"])) {
                 $profile["adress"] = stripslashes($profile["adress"]);
             }
-            if (isset($profile["adress2"]))
-            {
+            if (isset($profile["adress2"])) {
                 $profile["adress2"] = stripslashes($profile["adress2"]);
             }
-            if (isset($profile["state"]))
-            {
+            if (isset($profile["state"])) {
                 $profile["state"] = stripslashes($profile["state"]);
             }
-            if (isset($profile["country"]))
-            {
+            if (isset($profile["country"])) {
                 $profile["country"] = stripslashes($profile["country"]);
             }
             $tagsobj = new tags();
@@ -320,9 +259,7 @@ class user
             $profile["role"] = $rolesobj->getUserRole($profile["ID"]);
 
             return $profile;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -336,17 +273,14 @@ class user
     function getAvatar($id)
     {
         $id = (int) $id;
-
-        $sel = mysql_query("SELECT avatar FROM user WHERE ID = $id");
-        $profile = mysql_fetch_row($sel);
+        global $conn;
+        $sel = $conn->query("SELECT avatar FROM user WHERE ID = $id");
+        $profile = $sel->fetch();
         $profile = $profile[0];
 
-        if (!empty($profile))
-        {
+        if (!empty($profile)) {
             return $profile;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -360,18 +294,17 @@ class user
      */
     function login($user, $pass)
     {
-        if (!$user)
-        {
+        global $conn;
+
+        if (!$user) {
             return false;
         }
-        $user = mysql_real_escape_string($user);
-        $pass = mysql_real_escape_string($pass);
+        $user = $conn->quote($user);
         $pass = sha1($pass);
 
-        $sel1 = mysql_query("SELECT ID,name,locale,lastlogin,gender FROM user WHERE (name = '$user' OR email = '$user') AND pass = '$pass'");
-        $chk = mysql_fetch_array($sel1);
-        if ($chk["ID"] != "")
-        {
+        $sel1 = $conn->query("SELECT ID,name,locale,lastlogin,gender FROM user WHERE (name = $user OR email = $user) AND pass = '$pass'");
+        $chk = $sel1->fetch();
+        if ($chk["ID"] != "") {
             $rolesobj = new roles();
             $now = time();
             $_SESSION['userid'] = $chk['ID'];
@@ -385,19 +318,73 @@ class user
             $seid = session_id();
             $staylogged = getArrayVal($_POST, 'staylogged');
 
-            if ($staylogged == 1)
-            {
+            if ($staylogged == 1) {
                 setcookie("PHPSESSID", "$seid", time() + 14 * 24 * 3600);
             }
-            $upd1 = mysql_query("UPDATE user SET lastlogin = '$now' WHERE ID = $userid");
+            $upd1 = $conn->query("UPDATE user SET lastlogin = '$now' WHERE ID = $userid");
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
 
+    /**
+     * Log a user in
+     *
+     * @param string $user User name
+     * @param string $pass Password
+     * @return bool
+     */
+    function openIdLogin($url)
+    {
+        /* here the openid auth should take place */
+
+        try {
+            $openid = new LightOpenID($_SERVER['HTTP_HOST']);
+            if (!$openid->mode) {
+                $openid->identity = $url;
+                header('Location: ' . $openid->authUrl());
+            } elseif ($openid->mode == 'cancel') {
+                return false;
+            } else {
+                $identity = $openid->data['openid_identity'];
+
+                $sel1 = $conn->query("SELECT ID from openids WHERE identity='$identity'");
+                if ($row = $sel1->fetch()) {
+                    $id = $row['ID'];
+                } else return false;
+                // die("SELECT ID,name,locale,lastlogin,gender FROM user WHERE ID=$id");
+                $sel1 = $conn->query("SELECT ID,name,locale,lastlogin,gender FROM user WHERE ID=$id");
+                $chk = $sel1->fetch();
+                if ($chk["ID"] != "") {
+                    $rolesobj = new roles();
+                    $now = time();
+                    $_SESSION['userid'] = $chk['ID'];
+                    $_SESSION['username'] = stripslashes($chk['name']);
+                    $_SESSION['lastlogin'] = $now;
+                    $_SESSION['userlocale'] = $chk['locale'];
+                    $_SESSION['usergender'] = $chk['gender'];
+                    $_SESSION["userpermissions"] = $rolesobj->getUserRole($chk["ID"]);
+
+                    $userid = $_SESSION['userid'];
+                    $seid = session_id();
+                    $staylogged = getArrayVal($_POST, 'staylogged');
+
+                    if ($staylogged == 1) {
+                        setcookie("PHPSESSID", "$seid", time() + 14 * 24 * 3600);
+                    }
+                    $upd1 = $conn->prepare("UPDATE user SET lastlogin = ? WHERE ID = ?");
+                    $upd1Stmt = $upd1->execute(array($now,$userid));
+                    return true;
+                } else {
+                    return false;
+                }
+            }
+        }
+        catch(ErrorException $e) {
+            return false;
+        }
+    }
     /**
      * Logout
      *
@@ -420,10 +407,11 @@ class user
      */
     function getAllUsers($lim = 10)
     {
+        global $conn;
+
         $lim = (int) $lim;
 
-        $sel = mysql_query("SELECT COUNT(*) FROM `user`");
-        $num = mysql_fetch_row($sel);
+        $num = $conn->query("SELECT COUNT(*) FROM `user`")->fetch();
         $num = $num[0];
         SmartyPaginate::connect();
         // set items per page
@@ -433,26 +421,16 @@ class user
         $start = SmartyPaginate::getCurrentIndex();
         $lim = SmartyPaginate::getLimit();
 
-        $sel2 = mysql_query("SELECT * FROM `user` ORDER BY ID DESC LIMIT $start,$lim");
+        $sel2 = $conn->query("SELECT ID FROM `user` ORDER BY ID DESC LIMIT $start,$lim");
 
         $users = array();
-        while ($user = mysql_fetch_array($sel2))
-        {
-            $user["name"] = stripslashes($user["name"]);
-            $user["company"] = stripslashes($user["company"]);
-            $user["adress"] = stripslashes($user["adress"]);
-            $user["adress2"] = stripslashes($user["adress2"]);
-            $user["state"] = stripslashes($user["state"]);
-            $user["country"] = stripslashes($user["country"]);
-            array_push($users, $user);
+        while ($user = $sel2->fetch()) {
+            array_push($users, $this->getProfile($user["ID"]));
         }
 
-        if (!empty($users))
-        {
+        if (!empty($users)) {
             return $users;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -463,18 +441,19 @@ class user
      * @param int $offset Allowed time from last login
      * @return array $users
      */
-    function getOnlinelist($offset = 30)
+    function getOnlinelist($offset = 200)
     {
+        global $conn;
+
         $offset = (int) $offset;
         $time = time();
         $now = $time - $offset;
 
-        $sel = mysql_query("SELECT * FROM user WHERE lastlogin >= $now");
+        $sel = $conn->query("SELECT * FROM user WHERE lastlogin >= $now");
 
         $users = array();
 
-        while ($user = mysql_fetch_array($sel))
-        {
+        while ($user = $sel->fetch()) {
             $user["name"] = stripslashes($user["name"]);
             $user["company"] = stripslashes($user["company"]);
             $user["adress"] = stripslashes($user["adress"]);
@@ -484,12 +463,9 @@ class user
             array_push($users, $user);
         }
 
-        if (!empty($users))
-        {
+        if (!empty($users)) {
             return $users;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -497,27 +473,26 @@ class user
     /**
      * Is the given user logged in?
      *
-	 * @param int $user Member ID
+     * @param int $user Member ID
      * @param int $offset Allowed time from last login
      * @return bool
      */
     function isOnline($user, $offset = 30)
     {
+        global $conn;
+
         $user = (int) $user;
         $offset = (int) $offset;
 
         $time = time();
         $now = $time - $offset;
 
-        $sel = mysql_query("SELECT ID FROM user WHERE lastlogin >= $now AND ID = $user");
-        $user = mysql_fetch_row($sel);
+        $sel = $conn->query("SELECT ID FROM user WHERE lastlogin >= $now AND ID = $user");
+        $user = $sel->fetch();
 
-        if (!empty($user))
-        {
+        if (!empty($user)) {
             return true;
-        }
-        else
-        {
+        } else {
             return false;
         }
     }
@@ -528,23 +503,21 @@ class user
      * @param string $user Username
      * @return int $theid
      */
-    function getId($user){
-        $user = mysql_real_escape_string($user);
+    function getId($user)
+    {
+        global $conn;
 
-        $sel = mysql_query("SELECT ID FROM user WHERE name = '$user'");
-        $id = mysql_fetch_row($sel);
+        $sel = $conn->query("SELECT ID FROM user WHERE name = {$conn->quote($user)}");
+        $id = $sel->fetch();
         $id = $id[0];
 
         $theid = array();
 
         $theid["ID"] = $id;
 
-        if($id > 0)
-        {
+        if ($id > 0) {
             return $theid;
-        }
-        else
-        {
+        } else {
             return array();
         }
     }
