@@ -1299,13 +1299,18 @@ body a.butn_link, body a.butn_link_active {
 .message-in ul
 {
 padding-left;
+
 }
+
 message-in li
 {
 list-style-type: disc;
 padding: 0;
 }
-
+.message-in ul, .descript ul {
+list-style-type: disc;
+padding-left: 40px;
+}
 .message-in img {
 	height: auto;
 }
@@ -2610,6 +2615,7 @@ th.tools, td.tools {
 .files .second-thead, .files .second-thead:hover td, .files .block_in_wrapper, .files .inwrapper li:hover {
 	background: <?php echo $filesTableSecondhead;
 ?>;
+	cursor:move;
 }
 
 .files .color-a, .files .datepick table td, .files .datepick tr.head td, .files .staterow {
@@ -2729,7 +2735,16 @@ a.tool_edit, a.tool_del {
 	margin-right: 4px;
 	background: url(../images/butn-edit.png) no-repeat 0 4px;
 }
+a.tool_edit_active
+{
+	display: block;
+	width: 14px;
+	height: 23px;
+	float: left;
+	margin-right: 4px;
+	background: url(../images/butn-edit.png) no-repeat 0 -22px;
 
+}
 a.tool_del {
 	background-image: url(../images/butn-del.png);
 	margin: 0;
