@@ -1311,7 +1311,10 @@ message-in li
 list-style-type: disc;
 padding: 0;
 }
-
+.message-in ul, .descript ul {
+list-style-type: disc;
+padding-left: 40px;
+}
 .message-in img {
 	height: auto;
 }
@@ -2667,7 +2670,7 @@ th.tools, td.tools {
 span.acc-toggle, span.acc-toggle-active, .second-thead span.acc-toggle, .second-thead span.acc-toggle-active {
 	display: block;
 	width: 97%;
-	height: 15px;
+	height: 100%;
 	background: url(../images/acc-open.png) no-repeat right 10px;
 	cursor: pointer;
 
@@ -2735,7 +2738,16 @@ a.tool_edit, a.tool_del {
 	margin-right: 4px;
 	background: url(../images/butn-edit.png) no-repeat 0 4px;
 }
+a.tool_edit_active
+{
+	display: block;
+	width: 14px;
+	height: 23px;
+	float: left;
+	margin-right: 4px;
+	background: url(../images/butn-edit.png) no-repeat 0 -22px;
 
+}
 a.tool_del {
 	background-image: url(../images/butn-del.png);
 	margin: 0;
